<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
    xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">
  <xsl:output method="html" media-type="text/html" encoding="UTF-8"/>
  <xsl:param name="uuid" select="/Root/DeviceName" />
  <xsl:param name="count" select="/Root/DeviceName" />

  <xsl:variable name="MajorVersion" select="number(substring-before(/Root/ProductVersion, '.'))"/>

  <xsl:variable name="defsetting" select="document('conf:default.xml')/Root"/>

  <xsl:include href="Function.xslt"/>
  <xsl:include href="master/Section001.xslt"/>
  <xsl:include href="master/Section002.xslt"/>
  <xsl:include href="master/Section003.xslt"/>
  <xsl:include href="master/SectionSiri.xslt"/>
  <xsl:include href="master/SectionSpotlight.xslt"/>
  <xsl:include href="master/SectionVoiceOver.xslt"/>
  <xsl:include href="master/SectionAccessibility01.xslt"/>
  <xsl:include href="master/SectionAccessibility02.xslt"/>
  <xsl:include href="master/SectioniPad.xslt"/>
  <xsl:include href="master/Section004.xslt"/>
  <xsl:include href="master/SectionRestrict.xslt"/>
  <xsl:include href="master/SectionLocationService.xslt"/>
  <xsl:include href="master/SectionRestrict2.xslt"/>
  <xsl:include href="master/SectionLocale.xslt"/>
  <xsl:include href="master/SectionProfile.xslt"/>
  <xsl:include href="master/SectionScreen.xslt"/>
  <xsl:include href="master/SectionPasscode.xslt"/>
  <xsl:include href="master/SectionPrivacy.xslt"/>
  <xsl:include href="master/SectionStore.xslt"/>
  <xsl:include href="master/SectioniCloud.xslt"/>
  <xsl:include href="master/SectionAccount.xslt"/>
  <xsl:include href="master/SectionMail.xslt"/>
  <xsl:include href="master/SectionScreentime.xslt"/>
  <xsl:include href="master/SectionControlCenter.xslt"/>
  <xsl:include href="master/SectionBattery.xslt"/>
  <xsl:include href="master/SectionSOS.xslt"/>
  <xsl:include href="master/SectionWallet.xslt"/>

  <!--<xsl:include href="master/SectionApp.xslt"/>-->

  <xsl:template match="/">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="Root">
    <table id="mastertable">
      <tr id="tableheader">
        <th  class="t_top" colspan="6">設定項目</th>
        <th class="t_top" style="width:330px">マスターデバイスの設定値</th>
        <th class="t_top02 full">
          <input type="checkbox" id="checkAllfull" onclick="checkAll('full');" /><xsl:text>有効化</xsl:text>
        </th>
        <th class="t_top02 part">
          <input type="checkbox" id="checkAllpart" onclick="checkAll('part');" /><xsl:text>有効化</xsl:text>
        </th>
        <th class="t_top02 part">一致条件</th>
        <th class="t_top02 part">一致ワード</th>
        <th class="t_top02 part"><input type="checkbox" id="checkAlldupe" onclick="checkAll('dupe');" />重複を不許可</th>
        <th class="t_top02 check">有効化</th>
        <th class="t_top02 check">一致条件</th>
        <th class="t_top02 check">一致ワード</th>
        <th class="t_top02 check">重複を不許可</th>
      </tr>
      <xsl:call-template name="setting"/>
    </table>
  </xsl:template>
  <xsl:template name="setting">


    
    <xsl:call-template name="Section001"/>
    <xsl:if test="$MajorVersion &lt;= 11">
      <xsl:call-template name="SectionControlCenter"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &gt;= 12">
      <xsl:call-template name="SectionScreentime"/>
      <xsl:call-template name="SectionLocationService">
        <xsl:with-param name="privacy" select="0"/>
      </xsl:call-template>


      <xsl:call-template name="SectionRestrict2">
        <xsl:with-param name="gamecenter" select="0"/>
      </xsl:call-template>
    </xsl:if>
<!--一般 情報-->
    <xsl:call-template name="Section002"/>

<!--Siri-->
    <xsl:if test="$MajorVersion &gt;= 7 and $MajorVersion &lt;= 9">
      <xsl:call-template name="SectionSiri"/>
    </xsl:if>
    <xsl:if test="$MajorVersion &lt;= 10">
      <xsl:call-template name="SectionSpotlight"/>
    </xsl:if>
    <xsl:call-template name="Section003"/>
<!--アクセシビリティ VoiceOver-->
    <xsl:if test="$MajorVersion &lt; 13">
      <xsl:call-template name="SectionVoiceOver"/>

      <xsl:call-template name="SectionAccessibility01"/>
      <xsl:call-template name="SectionAccessibility02"/>
    </xsl:if>

<!--iPad用-->
    <xsl:if test="$MajorVersion &gt;= 8 and /Root/DeviceClass = 'iPad'">
      <xsl:call-template name="SectioniPad"/>
    </xsl:if>

    <xsl:call-template name="Section004"/>
<!--機能制限-->
    <xsl:if test="$MajorVersion &lt; 12">
      <xsl:call-template name="SectionRestrict"/>

      <xsl:if test="/Root/SBParentalControlsEnabled = 'true'">
        <xsl:call-template name="SectionLocationService"/>
      </xsl:if>

      <xsl:call-template name="SectionRestrict2"/>
    </xsl:if>

    <xsl:if test="$MajorVersion = 7 and /Root/DeviceClass = 'iPad'">
      <xsl:call-template name="SectioniPad"/>
    </xsl:if>
<!--日付と時刻-->
    <xsl:call-template name="SectionLocale"/>

<!--プロファイル-->
    <xsl:call-template name="SectionProfile"/>

    <xsl:if test="$MajorVersion &gt;= 12">
      <xsl:call-template name="SectionControlCenter"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &gt;= 9">
      <xsl:call-template name="SectionScreen"/>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 13">
      <xsl:call-template name="SectionVoiceOver"/>

      <xsl:call-template name="SectionAccessibility01"/>
      <xsl:call-template name="SectionAccessibility02"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionSiri"/>
    </xsl:if>
    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="SectionSpotlight"/>
    </xsl:if>
    
    <xsl:call-template name="SectionPasscode"/>

    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="SectionSOS"/>
      <xsl:call-template name="SectionBattery"/>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionLocationService">
        <xsl:with-param name="privacy" select="1"/>
      </xsl:call-template>
    </xsl:if>
	
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionPrivacy"/>
    </xsl:if>
	
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionStore"/>
    </xsl:if>

    <xsl:call-template name="SectionWallet"/>
    <xsl:call-template name="SectionAccount"/>

    <!--<xsl:call-template name="SectionApp"/>-->
    
    <!--<xsl:if test="/Root/GuidedAccessEnabled/text() = 'true'">
      <tr id="GAXProfileAllowsLockScreen">
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05">画面のスリープを許可</td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line04">
          <xsl:call-template name="defaultOff">
            <xsl:with-param name="bool" select="/Root/GAXProfileAllowsLockScreen/text()"/>
          </xsl:call-template>
        </td>
        <xsl:call-template name ="MasterSetting">
          <xsl:with-param name="name" select="'GAXProfileAllowsLockScreen'" />
          <xsl:with-param name="node" select="/Root/GAXProfileAllowsLockScreen"/>
        </xsl:call-template>
      </tr>
    </xsl:if>-->

    <!--<xsl:call-template name="SectionMail"/>-->
    

    <tr id="Applications">
      <td class="t_line05">アプリケーション</td>
      <td class="t_line05"></td>
       <td class="t_line05"></td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
        <td class="t_line04">
          <xsl:text>[順序をチェックしない]</xsl:text>
        </td>
        <xsl:call-template name ="MasterSetting">
          <xsl:with-param name="name" select="'Applications'" />
          <xsl:with-param name="node" select="/Root/Applications"/>
        </xsl:call-template>
    </tr>
    <xsl:for-each select="/Root/Applications/Application">
      <xsl:call-template name="Application">
        <xsl:with-param name="app" select="."/>
      </xsl:call-template>
    </xsl:for-each>

    <tr id="BookMarks">
      <td class="t_line05">
        <xsl:text>Safari</xsl:text>
      </td>
      <td class="t_line05">ブックマーク</td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line04"></td>
      <xsl:call-template name ="NoSetting" />
    </tr>
    
    <xsl:for-each select="/Root/Safari/BookMarks/BookMark">
      <xsl:if test="not(Folder) or (Folder and Folder != 'com.apple.ReadingList' and Folder != 'com.apple.WebFilterWhiteList')">
        <xsl:call-template name="BookMark">
          <xsl:with-param name="bm" select="."/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>

    <tr id="Safari/HasHistory">
      <td class="t_line05"></td>
      <td class="t_line05">閲覧履歴</td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line04">
        <xsl:text>[閲覧履歴なし（無いことをチェック）]</xsl:text>
      </td>
      <xsl:call-template name ="MasterSetting">
        <xsl:with-param name="name" select="'Safari/HasHistory'" />
        <xsl:with-param name="node" select="Safari/HasHistory"/>
      </xsl:call-template>
    </tr>
  </xsl:template>

  
  <!--設定値がない時空白になる-->
  <xsl:template name="OnOff">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-on">オン</xsl:param>
    <xsl:param name="label-off">オフ</xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'true'">
        <xsl:value-of select="$label-on"/>
      </xsl:when>
      <xsl:when test="$bool = 'false'">
        <xsl:value-of select="$label-off"/>
      </xsl:when>
    </xsl:choose>
  </xsl:template>
  <!--設定値がない時オフになる-->
  <xsl:template name="defaultOff">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-on">オン</xsl:param>
    <xsl:param name="label-off">オフ</xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'true' or $bool = '1'">
        <xsl:value-of select="$label-on"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-off"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--設定値がない時オンになる-->
  <xsl:template name="defaultOn">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-on">オン</xsl:param>
    <xsl:param name="label-off">オフ</xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:value-of select="$label-off"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-on"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--false時オンになる-->
  <xsl:template name="falseOn">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-false">オン</xsl:param>
    <xsl:param name="label-true">オフ</xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:value-of select="$label-false"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-true"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="TrueFalse">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-true">オン</xsl:param>
    <xsl:param name="label-false">オフ</xsl:param>
    <xsl:param name="label-other"></xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'true'">
        <xsl:value-of select="$label-true"/>
      </xsl:when>
      <xsl:when test="$bool = 'false'">
        <xsl:value-of select="$label-false"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-other"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!--false時オンになる-->
  <xsl:template name="falseOndefaultOff">
    <xsl:param name="bool" select="1"/>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="$bool = 'true'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>オフ</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--false時オンになる-->
  <xsl:template name="falseOndefaultOn">
    <xsl:param name="bool" select="1"/>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="$bool = 'true'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>オン</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  

  
  
  <xsl:template name="MasterSetting">
    <xsl:param name="name" select="1"/>
    <xsl:param name="node" select="1"/>
    <xsl:param name="create" />
    <td>
      <xsl:attribute name="class">t_line06 full</xsl:attribute>

      <xsl:if test="$create = 'true'">
        <input type="hidden">
          <xsl:attribute name="name"><xsl:value-of select="$name"></xsl:value-of>_create</xsl:attribute>
          <xsl:attribute name="value" >true</xsl:attribute>
        </input>
      </xsl:if>

	  <label>
	   <xsl:attribute name="style">display:block;width:100%;</xsl:attribute>
		
      <input type="checkbox">
        <xsl:attribute name="name"><xsl:value-of select="$name"></xsl:value-of>_full</xsl:attribute>
        <xsl:attribute name="id"><xsl:value-of select="$name"></xsl:value-of>_full</xsl:attribute>
        <xsl:attribute name="onclick">ExclusiveCheck('<xsl:value-of select="$name"></xsl:value-of>');toggleElement2('<xsl:value-of select="$name"></xsl:value-of>_full');</xsl:attribute>
        <xsl:if test="contains($node/@rule, 'Full') or $node/@rule = 'IgnoreOrder' or $node/@rule = 'LocaleAuto' or $node/@rule = 'LocaleDetail' or $node/@rule = 'LocaleCalendar' or $node/@rule = 'LocaleFormat' or $node/@rule = 'TimeZone' or $node/@rule = 'AppleKeyboards2' or $node/@rule = 'AppleKeyboards3' or $node/@rule = 'Included' or $node/@rule = 'TripleClickChoice'">
          <xsl:attribute name="checked">checked</xsl:attribute>
        </xsl:if>
      </input>
	  </label>

      <!--キーボードの順序をチェックするか-->
      <xsl:if test="$name = 'AppleKeyboards'">
        <br/>
        <br/>
      <div id="AppleKeyboards_div_margin"></div>
      <input type="checkbox" name="AppleKeyboards_margin" id="AppleKeyboards_margin" value="1">
        <xsl:if test="$node/@margin = '1'">
          <xsl:attribute name="checked">checked</xsl:attribute>
        </xsl:if>
      </input>

      </xsl:if>

      <!--Siriショートカット-->
      <xsl:if test="$name = 'SiriMyShortcuts'">
        <input type="hidden" name="SiriMyShortcuts_margin" id="SiriMyShortcuts_margin" value="1" />
      </xsl:if>
      

      <xsl:if test="$name = 'VoiceOverTouchSpeakingRate' or $name = 'QuickSpeakRate' or $name = 'MasterStereoBalance' or $name = 'QuickSpeakRate8' or $name = 'SBBacklightLevel2' or $name = 'CBBlueLightReductionCCTTargetRaw'">
        <div>
          <xsl:attribute name="id"><xsl:value-of select="$name"/>_div_margin</xsl:attribute>
          <xsl:text>誤差許容範囲</xsl:text>
          <select>
          <xsl:attribute name="name"><xsl:value-of select="$name"/>_margin</xsl:attribute>
          <option value="0">
            <xsl:if test ="$node/@margin = '0'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>0%</option>
          <option value="0.1">
            <xsl:if test ="$node/@margin = '0.1'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>10%</option>
          <option value="0.2">
            <xsl:if test ="$node/@margin = '0.2'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>20%</option>
          <option value="0.3">
            <xsl:if test ="$node/@margin = '0.3'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>30%</option>
          <option value="0.4">
            <xsl:if test ="$node/@margin = '0.4'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>40%</option>
          <option value="0.5">
            <xsl:if test ="$node/@margin = '0.5'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>50%</option>
        </select>
        </div>
      </xsl:if>
       <xsl:if test="$name = 'DeviceDate'">
        <div>
          <xsl:attribute name="id"><xsl:value-of select="$name"/>_div_margin</xsl:attribute>
          <xsl:text>誤差時間</xsl:text>
          <select>
          <xsl:attribute name="name"><xsl:value-of select="$name"/>_margin</xsl:attribute>
          <option value="5">
            <xsl:if test ="$node/@margin = '5'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>5秒</option>
          <option value="10">
            <xsl:if test ="$node/@margin = '10'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>10秒</option>
          <option value="15">
            <xsl:if test ="$node/@margin = '15'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>15秒</option>
          <option value="30">
            <xsl:if test ="$node/@margin = '30'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>30秒</option>
          <option value="60">
            <xsl:if test ="$node/@margin = '60'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>60秒</option>
          <option value="120">
            <xsl:if test ="$node/@margin = '120'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>120秒</option>
          <option value="180">
            <xsl:if test ="$node/@margin = '180'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>180秒</option>
          <option value="300">
            <xsl:if test ="$node/@margin = '300'">
              <xsl:attribute name="selected">selected</xsl:attribute>
            </xsl:if>300秒</option>
        </select>
        </div>
      </xsl:if>
      <xsl:if test="$name = 'BatteryCapacity'">
        <div>
          <xsl:attribute name="id"><xsl:value-of select="$name"/>_div_margin</xsl:attribute>
          <select>
            <xsl:attribute name="name"><xsl:value-of select="$name"/>_margin</xsl:attribute>
            <option value="50">
              <xsl:if test ="$node/@margin = '50'">
                <xsl:attribute name="selected">selected</xsl:attribute>
              </xsl:if><xsl:text>50%以上</xsl:text>
            </option>
            <option value="60">
              <xsl:if test ="$node/@margin = '60'">
                <xsl:attribute name="selected">selected</xsl:attribute>
              </xsl:if><xsl:text>60%以上</xsl:text>
            </option>
            <option value="70">
              <xsl:if test ="$node/@margin = '70'">
                <xsl:attribute name="selected">selected</xsl:attribute>
              </xsl:if><xsl:text>70%以上</xsl:text>
            </option>
            <option value="80">
              <xsl:if test ="$node/@margin = '80'">
                <xsl:attribute name="selected">selected</xsl:attribute>
              </xsl:if><xsl:text>80%以上</xsl:text>
            </option>
            <option value="90">
              <xsl:if test ="$node/@margin = '90'">
                <xsl:attribute name="selected">selected</xsl:attribute>
              </xsl:if><xsl:text>90%以上</xsl:text>
            </option>
            <option value="100">
              <xsl:if test ="$node/@margin = '100'">
                <xsl:attribute name="selected">selected</xsl:attribute>
              </xsl:if><xsl:text>100%</xsl:text>
            </option>
          </select>
        </div>
      </xsl:if>
    </td>
        <td>
          <xsl:attribute name="class">t_line06 part</xsl:attribute>          
          <input type="checkbox">
            <xsl:attribute name="name"><xsl:value-of select="$name"></xsl:value-of>_part</xsl:attribute>
            <xsl:attribute name="id"><xsl:value-of select="$name"></xsl:value-of>_part</xsl:attribute>
            <xsl:attribute name="onclick">toggleElement2('<xsl:value-of select="$name"></xsl:value-of>_part')</xsl:attribute>
            <xsl:if test="contains($node/@rule, 'Front') or contains($node/@rule, 'Rear') or contains($node/@rule, 'ExcludeChild')">
              <xsl:attribute name="checked"></xsl:attribute>
            </xsl:if>
          </input>
        </td>
    <td>
      <xsl:attribute name="class">t_line06 part</xsl:attribute>
      <select>
        <xsl:attribute name="name"><xsl:value-of select="$name"></xsl:value-of>_match</xsl:attribute>
        <xsl:if test="$name = 'Listofknownnetworks'">
          <option>
            <xsl:attribute name="value" >Full</xsl:attribute>
            <xsl:if test="contains($node/@rule, 'Comp')">
              <xsl:attribute name="selected"></xsl:attribute>
            </xsl:if>
            <xsl:text>完全一致</xsl:text>
          </option>
        </xsl:if>
        <option>
          <xsl:attribute name="value" >Front</xsl:attribute>
          <xsl:if test="contains($node/@rule, 'Front') or contains($node/@rule, 'Starts')">
            <xsl:attribute name="selected"></xsl:attribute>
          </xsl:if>
          <xsl:text>前方一致</xsl:text>
        </option>
        <option>
          <xsl:attribute name="value" >Rear</xsl:attribute>  
          <xsl:if test="not(contains($node/@rule, 'Front')) and (contains($node/@rule, 'Rear') or contains($node/@rule, 'Ends'))">
            <xsl:attribute name="selected"></xsl:attribute>
          </xsl:if>
          <xsl:text>後方一致</xsl:text>
        </option>
      </select>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 part</xsl:attribute>
      <input type="text" size="10">
        <xsl:attribute name="name"><xsl:value-of select="$name"></xsl:value-of>_text</xsl:attribute>
        <xsl:attribute name="value"><xsl:value-of select="$node/@compare"/></xsl:attribute>
      </input>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 part</xsl:attribute>
      <xsl:if test="$name != 'Listofknownnetworks'">
        <input type="checkbox">
          <xsl:attribute name="name"><xsl:value-of select="$name"></xsl:value-of>_dupe</xsl:attribute>
          <xsl:attribute name="id"><xsl:value-of select="$name"></xsl:value-of>_dupe</xsl:attribute>
          <xsl:attribute name="onclick">toggleElement2('<xsl:value-of select="$name"></xsl:value-of>_dupe')</xsl:attribute>
          <xsl:if test="$node/@unique = 'on'">
            <xsl:attribute name="checked"></xsl:attribute>
          </xsl:if>
        </input>
      </xsl:if>
    </td>
        <td>
          <xsl:attribute name="class">t_line06 check</xsl:attribute>
        </td>
        <td>
          <xsl:attribute name="class">t_line06 check</xsl:attribute>
        </td>
        <td>
          <xsl:attribute name="class">t_line06 check</xsl:attribute>
        </td>
        <td>
          <xsl:attribute name="class">t_line06 check</xsl:attribute>
        </td>
  </xsl:template>
 
  
  <xsl:template name="NoSetting">
    <td>
      <xsl:attribute name="class">t_line06 full</xsl:attribute>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 part</xsl:attribute>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 part</xsl:attribute>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 part</xsl:attribute>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 part</xsl:attribute>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 check</xsl:attribute>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 check</xsl:attribute>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 check</xsl:attribute>
    </td>
    <td>
      <xsl:attribute name="class">t_line06 check</xsl:attribute>
    </td>
  </xsl:template>

  <xsl:template name="Application">
    <xsl:param name="app"/>
    <xsl:if test="Page and NewPage">
      <tr>
        <xsl:attribute name="id">Applications/Application_<xsl:value-of select="Page"/></xsl:attribute>
        <td class="t_line05">
          <xsl:choose>
            <xsl:when test="Page = '-1'">
              <xsl:text>ドック</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>ホーム画面</xsl:text><xsl:value-of select="number(Page) + 1"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line04"></td>
        <xsl:call-template name ="NoSetting" />
      </tr>
    </xsl:if>
    <xsl:if test="Folder and FirstChildren = 'true'">
      <tr>
        <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/Folder</xsl:attribute>
        <td class="t_line05"></td>
        <td class="t_line05">フォルダ名</td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line04">
          <xsl:value-of select="Folder"/>
        </td>
        <xsl:call-template name ="MasterSetting">
          <xsl:with-param name="name" select="concat('Applications/Application_',position(),'/Folder')" />
          <xsl:with-param name="node" select="Folder"/>
        </xsl:call-template>
      </tr>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="URL and Title">
        <tr>
          <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/Title</xsl:attribute>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05">
            <xsl:text>アプリケーション</xsl:text><xsl:value-of select="position()"/>
          </td>
          <td class="t_line05">
            <xsl:text>名前</xsl:text>
          </td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04">
            <xsl:value-of select="Title"/>
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Applications/Application_',position(),'/Title')" />
            <xsl:with-param name="node" select="Title"/>
          </xsl:call-template>
        </tr>
        <tr>
          <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/URL</xsl:attribute>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05"></td>
          <td class="t_line05">
            <xsl:text>URL</xsl:text>
          </td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04 wordbreak">
            <xsl:value-of select="URL"/>
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Applications/Application_',position(),'/URL')" />
            <xsl:with-param name="node" select="URL"/>
          </xsl:call-template>
        </tr>
      </xsl:when>
      <xsl:when test="DefaultApp = 'true'">
        <tr>
          <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/CFBundleIdentifier</xsl:attribute>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05">
            <xsl:text>アプリケーション</xsl:text><xsl:value-of select="position()"/>
          </td>
          <td class="t_line05">
            <xsl:text>名前</xsl:text>
          </td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04">
            <xsl:call-template name="DefaultApp">
              <xsl:with-param name="appID" select="CFBundleIdentifier"/>
              <xsl:with-param name="device" select="/Root/DeviceClass"/>
            </xsl:call-template>
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Applications/Application_',position(),'/CFBundleIdentifier')" />
            <xsl:with-param name="node" select="CFBundleIdentifier"/>
          </xsl:call-template>
        </tr>
      </xsl:when>
      <xsl:otherwise>
        <tr>
          <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/CFBundleDisplayName</xsl:attribute>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05">
            <xsl:text>アプリケーション</xsl:text><xsl:value-of select="position()"/>
          </td>
          <td class="t_line05">
            <xsl:text>名前</xsl:text>
          </td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04">
            <xsl:value-of select="CFBundleDisplayName" />
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Applications/Application_',position(),'/CFBundleDisplayName')" />
            <xsl:with-param name="node" select="CFBundleDisplayName"/>
          </xsl:call-template>
        </tr>
        <tr>
          <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/CFBundleVersion</xsl:attribute>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05"></td>
          <td class="t_line05">バージョン</td>
          <td class="t_line05">リリースバージョン</td>
          <td class="t_line05"></td>
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04">
            <xsl:value-of select="CFBundleVersion" />
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Applications/Application_',position(),'/CFBundleVersion')" />
            <xsl:with-param name="node" select="CFBundleVersion"/>
          </xsl:call-template>
        </tr>
        <tr>
          <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/CFBundleShortVersionString</xsl:attribute>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05">ビルドバージョン</td>
          <td class="t_line05"></td>
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04">
            <xsl:value-of select="CFBundleShortVersionString" />
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Applications/Application_',position(),'/CFBundleShortVersionString')" />
            <xsl:with-param name="node" select="CFBundleShortVersionString"/>
          </xsl:call-template>
        </tr>
        <tr>
          <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/CFBundleIdentifier</xsl:attribute>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05"></td>
          <td class="t_line05">識別子</td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04">
            <xsl:value-of select="CFBundleIdentifier" />
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Applications/Application_',position(),'/CFBundleIdentifier')" />
            <xsl:with-param name="node" select="CFBundleIdentifier"/>
          </xsl:call-template>
        </tr>
      </xsl:otherwise>
    </xsl:choose>

  </xsl:template>

  <xsl:template name="BookMark">
    <xsl:param name="bm"/>
    <xsl:if test="Folder and (First = 'true' or Empty = 'true')">
      <tr>
        <xsl:attribute name="id">Safari/BookMarks/BookMark_<xsl:value-of select="position()"/>/Folder</xsl:attribute>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05">フォルダ名</td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line04">
          <xsl:choose>
            <xsl:when test="Special = 'true' and Folder = 'BookmarksBar'">
              <xsl:text>お気に入り</xsl:text>
            </xsl:when>
            <xsl:when test="Special = 'true' and Folder = 'com.apple.ReadingList'">
              <xsl:text>リーディングリスト</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="Folder"/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <xsl:call-template name ="MasterSetting">
          <xsl:with-param name="name" select="concat('Safari/BookMarks/BookMark_',position(),'/Folder')" />
          <xsl:with-param name="node" select="Folder"/>
        </xsl:call-template>
      </tr>
    </xsl:if>
    
      <xsl:if test="URL and Title">
        <tr>
          <xsl:attribute name="id">Safari/BookMarks/BookMark_<xsl:value-of select="position()"/>/Title</xsl:attribute>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05">
            <xsl:text>ブックマーク</xsl:text>
          </td>
          <td class="t_line05">
            <xsl:text>タイトル</xsl:text>
          </td>
          <td class="t_line05"></td>
          
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04 wordbreak">
            <xsl:value-of select="Title"/>
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Safari/BookMarks/BookMark_',position(),'/Title')" />
            <xsl:with-param name="node" select="Title"/>
          </xsl:call-template>
        </tr>
        <tr>
          <xsl:attribute name="id">Safari/BookMarks/BookMark_<xsl:value-of select="position()"/>/URL</xsl:attribute>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05"></td>
          <td class="t_line05">
            <xsl:text>URL</xsl:text>
          </td>
          <td class="t_line05"></td>
          
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line04 wordbreak">
            <xsl:value-of select="URL"/>
          </td>
          <xsl:call-template name ="MasterSetting">
            <xsl:with-param name="name" select="concat('Safari/BookMarks/BookMark_',position(),'/URL')" />
            <xsl:with-param name="node" select="URL"/>
          </xsl:call-template>
        </tr>
      </xsl:if>

  </xsl:template>

  <xsl:template name="settingtable">
    <xsl:param name="id"/>
    <!--表示名を指定-->
    <xsl:param name="title1"/>
    <xsl:param name="title2"/>
    <xsl:param name="title3"/>
    <xsl:param name="title4"/>
    <xsl:param name="title5"/>
    <xsl:param name="title6"/>
    <xsl:param name="template"/>
    <xsl:param name="valueNode"/>
    <xsl:param name="value"/>
    <xsl:param name="create"/>
    <xsl:param name="param1"/>
    <xsl:param name="param2"/>
	<!-- <xsl:if test="$title1"> -->
	  <!-- <tr> -->
		<!-- <th class="t_section" colspan="6"> -->
		<!-- <a name="{$id}"><xsl:value-of select="$title1"/></a> -->
		<!-- </th> -->
		<!-- <th colspan="10"> -->
		<!-- </th> -->
	  <!-- </tr> -->
	<!-- </xsl:if> -->
  <tr>
    <xsl:attribute name="id"><xsl:value-of select="$id"/></xsl:attribute>
    <td class="t_line05 wordbreak"><xsl:value-of select="$title1"/></td>
    <td class="t_line05 wordbreak"><xsl:value-of select="$title2"/></td>
    <td class="t_line05 wordbreak"><xsl:value-of select="$title3"/></td>
    <td class="t_line05 wordbreak"><xsl:value-of select="$title4"/></td>
    <td class="t_line05 wordbreak"><xsl:value-of select="$title5"/></td>
    <td class="t_line05 wordbreak"><xsl:value-of select="$title6"/></td>
    <td class="t_line04 wordbreak">
       <xsl:copy-of select="$value"/>
      <xsl:if test="$template">
        <xsl:choose>
          <xsl:when test="$template = 'text'">
            <xsl:value-of select="$valueNode"/>
          </xsl:when>
          <xsl:when test="$template = 'defaultOff'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="defaultOff">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="defaultOff">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'defaultOn'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="defaultOn">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="defaultOn">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'OnOff'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="OnOff">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="OnOff">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'strOnOff'">
            <xsl:call-template name="strOnOff">
              <xsl:with-param name="value" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'falseOn'">
            <xsl:call-template name="falseOn">
              <xsl:with-param name="bool" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Orientation'">
            <xsl:call-template name="Orientation">
              <xsl:with-param name="value" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization'">
            <xsl:call-template name="locationAuthorization">
              <xsl:with-param name="value" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization2'">
            <xsl:call-template name="locationAuthorization2">
              <xsl:with-param name="value" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization3'">
            <xsl:call-template name="locationAuthorization3">
              <xsl:with-param name="value" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
        </xsl:choose>
      </xsl:if>
    </td>
    <xsl:choose>
      <xsl:when test="not($valueNode)">
        <xsl:call-template name ="NoSetting" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name ="MasterSetting">
          <xsl:with-param name="name" select="$id" />
          <xsl:with-param name="node" select="$valueNode"/>
          <xsl:with-param name="create" select="$create"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </tr>
  </xsl:template>
  
</xsl:stylesheet>