<?xml version="1.0" encoding="UTF-8"?>
<!--デバイス設定一覧CSV 1台の突合結果-->
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
    xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">
  <xsl:output method="text" media-type="text/plain" encoding="UTF-8" indent="no"/>
  <xsl:param name="outputdate"/>
  <xsl:param name="devicename"/>
  <xsl:param name="mastername"/>
  <xsl:param name="modified"/>
  <xsl:param name="created"/>
  <xsl:param name="count"/>

  <xsl:variable name="MajorVersion" select="number(substring-before(/RESULT/ProductVersion, '.'))"/>

  <xsl:variable name="defsetting" select="document('conf:default.xml')/Root"/>
  
  <xsl:include href="Function.xslt" />
  <xsl:include href="csv/Section001.xslt"/>
  <xsl:include href="csv/Section002.xslt"/>
  <xsl:include href="csv/Section003.xslt"/>
  <xsl:include href="csv/SectionSiri.xslt"/>
  <xsl:include href="csv/SectionSpotlight.xslt"/>
  <xsl:include href="csv/SectionVoiceOver.xslt"/>
  <xsl:include href="csv/SectionAccessibility01.xslt"/>
  <xsl:include href="csv/SectionAccessibility02.xslt"/>
  <xsl:include href="csv/SectioniPad.xslt"/>
  <xsl:include href="csv/Section004.xslt"/>
  <xsl:include href="csv/SectionRestrict.xslt"/>
  <xsl:include href="csv/SectionLocationService.xslt"/>
  <xsl:include href="csv/SectionRestrict2.xslt"/>
  <xsl:include href="csv/SectionLocale.xslt"/>
  <xsl:include href="csv/SectionProfile.xslt"/>
  <xsl:include href="csv/SectionScreen.xslt"/>
  <xsl:include href="csv/SectionPasscode.xslt"/>
  <xsl:include href="csv/SectionPrivacy.xslt"/>
  <xsl:include href="csv/SectionStore.xslt"/>
  <xsl:include href="csv/SectioniCloud.xslt"/>
  <xsl:include href="csv/SectionAccount.xslt"/>
  <xsl:include href="csv/SectionMail.xslt"/>
  <xsl:include href="csv/SectionScreentime.xslt"/>
  <xsl:include href="csv/SectionControlCenter.xslt"/>
  <xsl:include href="csv/SectionBattery.xslt"/>
  <xsl:include href="csv/SectionSOS.xslt"/>
  <xsl:include href="csv/SectionWallet.xslt"/>
  
  <xsl:template match="/">
    <xsl:text>デバイス設定一覧</xsl:text>
    <xsl:text>&#x20;&#x0a;</xsl:text>

    <xsl:text>出力日時,</xsl:text>
    <xsl:value-of select="$outputdate"/>
    <xsl:text>&#x20;&#x0a;</xsl:text>
    <xsl:text>&#x20;&#x0a;</xsl:text>

    <xsl:text>デバイス名,</xsl:text>
    <xsl:value-of select="$devicename"/>
    <xsl:text>,取得日時,</xsl:text>
    <xsl:value-of select="$created"/>
    <xsl:text>&#x20;&#x0a;</xsl:text>
    <xsl:text>マスター設定デバイス名,"=""</xsl:text>
    <xsl:value-of select="$mastername"/>
    <xsl:text>""",最終更新日時,</xsl:text>
    <xsl:value-of select="$modified"/>
    <xsl:text>&#x20;&#x0a;</xsl:text>
    <xsl:text>差異がある項目数,</xsl:text>
    <xsl:value-of select="$count"/>
    <xsl:text>&#x20;&#x0a;</xsl:text>

    <xsl:text>■デバイス設定</xsl:text>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="RESULT">
    <xsl:text>&#x20;&#x0a;</xsl:text>
    <xsl:text>項目(1),項目(2),項目(3),項目(4),項目(5),項目(6),デバイスの設定値,差異,マスター設定値</xsl:text>
    <xsl:text>&#x20;&#x0a;</xsl:text>
    <xsl:call-template name="setting"/>
  </xsl:template>

  <xsl:template name="setting">

    <xsl:call-template name="Section001"/>

    <xsl:if test="$MajorVersion &lt;= 11">
      <xsl:call-template name="SectionControlCenter"/>
    </xsl:if>
    <xsl:if test="$MajorVersion &gt;= 12">
      <xsl:call-template name="SectionScreentime"/>
      <xsl:call-template name="SectionLocationService">
        <xsl:with-param name="privacy" select="0"/>
      </xsl:call-template>

      <xsl:call-template name="SectionRestrict2">
        <xsl:with-param name="gamecenter" select="0"/>
      </xsl:call-template>
    </xsl:if>
	
    <xsl:call-template name="Section002"/>

    <xsl:if test="$MajorVersion &gt;= 7 and $MajorVersion &lt;= 9">
      <xsl:call-template name="SectionSiri"/>
    </xsl:if>
    <xsl:if test="$MajorVersion &lt;= 10">
      <xsl:call-template name="SectionSpotlight"/>
    </xsl:if>
    <xsl:call-template name="Section003"/>

    <xsl:if test="$MajorVersion &lt; 13">
      <xsl:call-template name="SectionVoiceOver"/>

      <xsl:call-template name="SectionAccessibility01"/>
      <xsl:call-template name="SectionAccessibility02"/>
    </xsl:if>

    <!--iPad用-->
    <xsl:if test="$MajorVersion &gt;= 8 and /RESULT/DeviceClass = 'iPad'">
      <xsl:call-template name="SectioniPad"/>
    </xsl:if>

    <xsl:call-template name="Section004"/>

    <!--機能制限-->
    <xsl:if test="$MajorVersion &lt; 12">
    <xsl:call-template name="SectionRestrict"/>
    <xsl:if test="/RESULT/SBParentalControlsEnabled = 'true'">
      <xsl:call-template name="SectionLocationService"/>
    </xsl:if>
     <xsl:call-template name="SectionRestrict2"/>
    </xsl:if>

    <xsl:if test="$MajorVersion = 7 and /RESULT/DeviceClass = 'iPad'">
      <xsl:call-template name="SectioniPad"/>
    </xsl:if>
    <!--日付と時刻-->
    <xsl:call-template name="SectionLocale"/>
    <!--プロファイル-->
    <xsl:call-template name="SectionProfile"/>

    <xsl:if test="$MajorVersion &gt;= 12">
      <xsl:call-template name="SectionControlCenter"/>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 9">
      <xsl:call-template name="SectionScreen"/>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 13">
      <xsl:call-template name="SectionVoiceOver"/>

      <xsl:call-template name="SectionAccessibility01"/>
      <xsl:call-template name="SectionAccessibility02"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionSiri"/>
    </xsl:if>
    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="SectionSpotlight"/>
    </xsl:if>

    <xsl:call-template name="SectionPasscode"/>

    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="SectionSOS"/>
      <xsl:call-template name="SectionBattery"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionLocationService">
        <xsl:with-param name="privacy" select="1"/>
      </xsl:call-template>
    </xsl:if>
	
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionPrivacy"/>
    </xsl:if>
	
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionStore"/>
    </xsl:if>

    <xsl:call-template name="SectionWallet"/>
    <xsl:call-template name="SectionAccount"/>

    <xsl:text>アプリケーション,,,,,,,</xsl:text>
    <xsl:text>&#x20;&#x0a;</xsl:text>

    <xsl:for-each select="Applications/Application">
      <xsl:if  test="Page and NewPage">
        <xsl:choose>
          <xsl:when test="Page = '-1'">
            <xsl:text>ドック</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>ホーム画面</xsl:text>
            <xsl:value-of select="number(Page) + 1"/>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#x20;&#x0a;</xsl:text>
      </xsl:if>
      <xsl:if test="Folder and FirstChildren = 'true'">

        <xsl:text>,フォルダ名,,,,,"=""</xsl:text>
        <xsl:value-of select="Folder" />
        <xsl:text>""",</xsl:text>
        <xsl:call-template name="sign">
          <xsl:with-param name="this" select="Folder"/>
        </xsl:call-template>
        <xsl:value-of select="Folder/@master" />
        <xsl:text>&#x20;&#x0a;</xsl:text>
      </xsl:if>


      <xsl:choose>
        <xsl:when test="URL and Title">
          <xsl:text>,</xsl:text>
          <xsl:if test="Folder">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>アプリケーション</xsl:text>
          <xsl:value-of select="position()"/>
          <xsl:text>,名前,,,</xsl:text>
          <xsl:if test="not(Folder)">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="Title" />
          <xsl:text>""",</xsl:text>
          <xsl:call-template name="sign">
            <xsl:with-param name="this" select="Title"/>
          </xsl:call-template>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="Title/@master" />
          <xsl:text>""",</xsl:text>
          <xsl:text>&#x20;&#x0a;</xsl:text>

          <xsl:text>,</xsl:text>
          <xsl:if test="Folder">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>,URL,,,</xsl:text>
          <xsl:if test="not(Folder)">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="URL" />
          <xsl:text>""",</xsl:text>
          <xsl:call-template name="sign">
            <xsl:with-param name="this" select="URL"/>
          </xsl:call-template>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="URL/@master" />
          <xsl:text>""",</xsl:text>
          <xsl:text>&#x20;&#x0a;</xsl:text>
        </xsl:when>

        <xsl:when test="DefaultApp">
          <xsl:text>,</xsl:text>
          <xsl:if test="Folder">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>アプリケーション</xsl:text>
          <xsl:value-of select="position()"/>
          <xsl:text>,名前,,,</xsl:text>
          <xsl:if test="not(Folder)">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>"=""</xsl:text>
          <xsl:call-template name="DefaultApp">
            <xsl:with-param name="appID" select="CFBundleIdentifier"/>
            <xsl:with-param name="device" select="/RESULT/DeviceClass"/>
          </xsl:call-template>
          <xsl:text>""",</xsl:text>
          <xsl:call-template name="sign">
            <xsl:with-param name="this" select="CFBundleIdentifier"/>
          </xsl:call-template>
          <xsl:text>"=""</xsl:text>
          <xsl:call-template name="DefaultApp">
            <xsl:with-param name="appID" select="CFBundleIdentifier/@master"/>
            <xsl:with-param name="device" select="/RESULT/DeviceClass/@master"/>
          </xsl:call-template>
          <xsl:text>"""</xsl:text>
          <xsl:text>&#x20;&#x0a;</xsl:text>
        </xsl:when>

        <xsl:otherwise>
          <xsl:text>,</xsl:text>
          <xsl:if test="Folder">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>アプリケーション</xsl:text>
          <xsl:value-of select="position()"/>
          <xsl:text>,名前,,,</xsl:text>
          <xsl:if test="not(Folder)">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="CFBundleDisplayName" />
          <xsl:text>""",</xsl:text>
          <xsl:call-template name="sign">
            <xsl:with-param name="this" select="CFBundleDisplayName"/>
          </xsl:call-template>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="CFBundleDisplayName/@master" />
          <xsl:text>"""</xsl:text>
          <xsl:text>&#x20;&#x0a;</xsl:text>

          <xsl:text>,</xsl:text>
          <xsl:if test="Folder">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>,バージョン,リリースバージョン,,</xsl:text>
          <xsl:if test="not(Folder)">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="CFBundleVersion" />
          <xsl:text>""",</xsl:text>
          <xsl:call-template name="sign">
            <xsl:with-param name="this" select="CFBundleVersion"/>
          </xsl:call-template>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="CFBundleVersion/@master" />
          <xsl:text>"""</xsl:text>

          <xsl:text>&#x20;&#x0a;</xsl:text>
          <xsl:text>,</xsl:text>
          <xsl:if test="Folder">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>,,ビルドバージョン,,</xsl:text>
          <xsl:if test="not(Folder)">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="CFBundleShortVersionString" />
          <xsl:text>""",</xsl:text>
          <xsl:call-template name="sign">
            <xsl:with-param name="this" select="CFBundleShortVersionString"/>
          </xsl:call-template>
          <xsl:text>"=""</xsl:text>
          <xsl:value-of select="CFBundleShortVersionString/@master" />
          <xsl:text>"""</xsl:text>

          <xsl:text>&#x20;&#x0a;</xsl:text>
          <xsl:text>,</xsl:text>
          <xsl:if test="Folder">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:text>,識別子,,,</xsl:text>
          <xsl:if test="not(Folder)">
            <xsl:text>,</xsl:text>
          </xsl:if>
          <xsl:call-template name="text">
            <xsl:with-param name="this" select="CFBundleIdentifier"/>
          </xsl:call-template>
          <xsl:text>&#x20;&#x0a;</xsl:text>
        </xsl:otherwise>
      </xsl:choose>


    </xsl:for-each>

    <xsl:text>Safari,ブックマーク,,,,,,</xsl:text>
    <xsl:for-each select="/RESULT/Safari/BookMarks/BookMark">
      <xsl:if test="not(Special) or Folder != 'com.apple.ReadingList'">
        <xsl:call-template name="BookMark">
          <xsl:with-param name="bm" select="."/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
    <xsl:text>&#x20;&#x0a;</xsl:text>

    <xsl:text>,閲覧履歴,,,,,</xsl:text>
    <xsl:choose>
      <xsl:when test="Safari/HasHistory = 'true'">
        <xsl:text>あり</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>なし</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="Safari/HasHistory"/>
    </xsl:call-template>
    <xsl:if test="Safari/HasHistory/@match">
      <xsl:text>[閲覧履歴なし]</xsl:text>
    </xsl:if>

  </xsl:template>

  <xsl:template name="sign">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="not($this/@match)">
        <xsl:text>-</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@match = 'true'">
        <xsl:text>○</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@match = 'false'">
        <xsl:text>×</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@match = 'extra'">
        <xsl:text>×</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@match = 'short'">
        <xsl:text>×</xsl:text>
      </xsl:when>
    </xsl:choose>
    <xsl:text>,</xsl:text>
  </xsl:template>

  <!--設定値がない時空白になる-->
  <xsl:template name="OnOff">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-on">オン</xsl:param>
    <xsl:param name="label-off">オフ</xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'true'">
        <xsl:value-of select="$label-on"/>
      </xsl:when>
      <xsl:when test="$bool = 'false'">
        <xsl:value-of select="$label-off"/>
      </xsl:when>
    </xsl:choose>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$bool"/>
    </xsl:call-template>
    <xsl:choose>
      <xsl:when test="not($bool/@master)"></xsl:when>
      <xsl:when test="$bool/@master = 'true'">
        <xsl:value-of select="$label-on"/>
      </xsl:when>
      <xsl:when test="$bool/@master = 'false'">
        <xsl:value-of select="$label-off"/>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!--設定値がない時オフになる-->
  <xsl:template name="defaultOff">
    <xsl:param name="bool"/>
    <xsl:param name="label-on">
      <xsl:text>オン</xsl:text>
    </xsl:param>
    <xsl:param name="label-off">
      <xsl:text>オフ</xsl:text>
    </xsl:param>
    <xsl:param name="empty">
      <xsl:text>false</xsl:text>
    </xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'true' or $bool = '1'">
        <xsl:value-of select="$label-on"/>
      </xsl:when>
      <xsl:when test="not($bool) or $empty = 'true'"></xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-off"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$bool"/>
    </xsl:call-template>
    <xsl:choose>
      <xsl:when test="$bool/@master = 'true' or $bool/@master = '1'">
        <xsl:value-of select="$label-on"/>
      </xsl:when>
      <xsl:when test="not($bool/@master)"></xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-off"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--設定値がない時オンになる-->
  <xsl:template name="defaultOn">
    <xsl:param name="bool" select="1"/>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>オン</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$bool"/>
    </xsl:call-template>
    <xsl:choose>
      <xsl:when test="not($bool/@master)"></xsl:when>
      <xsl:when test="$bool/@master = 'false'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>オン</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--false時オンになる-->
  <xsl:template name="falseOn">
    <xsl:param name="bool" select="1"/>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="$bool = 'true'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:otherwise>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="TrueFalse">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-true">オン</xsl:param>
    <xsl:param name="label-false">オフ</xsl:param>
    <xsl:param name="label-other"></xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'true'">
        <xsl:value-of select="$label-true"/>
      </xsl:when>
      <xsl:when test="$bool = 'false'">
        <xsl:value-of select="$label-false"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-other"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--false時オンになる-->
  <xsl:template name="falseOndefaultOff">
    <xsl:param name="bool" select="1"/>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="$bool = 'true'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>オフ</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--false時オンになる-->
  <xsl:template name="falseOndefaultOn">
    <xsl:param name="bool" select="1"/>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="$bool = 'true'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:when test="not($bool)"></xsl:when>
      <xsl:otherwise>
        <xsl:text>オン</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--国名ISO 3166-1(レートの対象)-->
  <xsl:template name="countryname">
    <xsl:param name="this"/>
      <xsl:call-template name="country">
        <xsl:with-param name="countrycode" select="$this/text()"/>
      </xsl:call-template>
      <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
      <xsl:call-template name="country">
        <xsl:with-param name="countrycode" select="$this/@master"/>
      </xsl:call-template>
  </xsl:template>

  
  <xsl:template name="zeroIsOn">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="$this/text()='0'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="not($this)"></xsl:when>
      <xsl:otherwise>
        <xsl:text>オフ</xsl:text>
      </xsl:otherwise>
    </xsl:choose>,<xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template><xsl:choose>
      <xsl:when test="$this/@master='0'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="not($this/@master)"></xsl:when>
      <xsl:otherwise>
        <xsl:text>オフ</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
  </xsl:template>

  <xsl:template name="specifiedefSuffix">
    <xsl:param name="this"/>
    <xsl:param name="default"/>
    <xsl:param name="suffix" />
    <xsl:param name="except" />
    <xsl:param name="exdesc" />
    <xsl:choose>
      <xsl:when test="$except and $this = $except">
        <xsl:value-of select="$exdesc"/>
      </xsl:when>
      <xsl:when test="$this = ''">
        <xsl:value-of select="$default"/>
        <xsl:value-of select="$suffix"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$this"/>
        <xsl:value-of select="$suffix"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
    <xsl:call-template name ="sign">
      <xsl:with-param name="this" select="$this" />
    </xsl:call-template>
    <xsl:choose>
      <xsl:when test="$except and $this/@master = $except">
        <xsl:value-of select="$exdesc"/>
      </xsl:when>
      <xsl:when test="not($this/@master)"></xsl:when>
      <xsl:when test="$this/@master = ''">
        <xsl:value-of select="$default"/>
        <xsl:value-of select="$suffix"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$this/@master"/>
        <xsl:value-of select="$suffix"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
  </xsl:template>

  <xsl:template name="text">
    <xsl:param name="this"/>
    <xsl:text>"=""</xsl:text>
    <xsl:value-of select="$this/text()"/>
    <xsl:text>""",</xsl:text>
    <xsl:choose>
      <xsl:when test="$this/@unique = 'false'">
        <xsl:text>×重複</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@match = 'true' and ( not($this/@unique) or $this/@unique = 'true')">
        <xsl:text>○</xsl:text>
        <xsl:if test="$this/@unique = 'true'">
          <xsl:text>重複なし</xsl:text>
        </xsl:if>
      </xsl:when>
      <xsl:when test="not($this/@match) and $this/@unique = 'true'">
        <xsl:text>○重複なし</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@match = 'false'">
        <xsl:text>×</xsl:text>
      </xsl:when>
      <xsl:when test="not($this/@match)">
        <xsl:text>-</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@match = 'extra'">
        <xsl:text>×</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@match = 'short'">
        <xsl:text>×</xsl:text>
      </xsl:when>
    </xsl:choose>
    <xsl:text>,"=""</xsl:text>
    <xsl:value-of select="$this/@master"/>
    <xsl:if test="$this/@part">
      <xsl:choose>
        <xsl:when test="$this/@part = 'front'">
          <xsl:text>[前方一致]</xsl:text>
        </xsl:when>
        <xsl:when test="$this/@part = 'rear'">
          <xsl:text>[後方一致]</xsl:text>
        </xsl:when>
      </xsl:choose>
    </xsl:if>
    <xsl:text>""",</xsl:text>
  </xsl:template>
  
  <xsl:template name="Authorization">
    <xsl:param name="this"/>
    <xsl:call-template name="locationAuthorization">
      <xsl:with-param name="value" select="$this"/>
    </xsl:call-template>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <xsl:call-template name="locationAuthorization">
      <xsl:with-param name="value" select="$this/@master"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="Authorization2">
    <xsl:param name="this"/>
      <xsl:call-template name="locationAuthorization2">
        <xsl:with-param name="value" select="$this"/>
      </xsl:call-template>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <xsl:call-template name="locationAuthorization2">
      <xsl:with-param name="value" select="$this/@master"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="Authorization3">
    <xsl:param name="this"/>
    <xsl:call-template name="locationAuthorization3">
      <xsl:with-param name="value" select="$this"/>
    </xsl:call-template>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <xsl:call-template name="locationAuthorization3">
      <xsl:with-param name="value" select="$this/@master"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="MasterSetting">
    <xsl:param name="name" select="1"/>
    <xsl:param name="node" select="1"/>
    <xsl:if test="contains($node/@rule, 'Full') or $node/@rule = 'AppleKeyboards2' or $node/@rule = 'Included'">
      <xsl:text>○</xsl:text>
    </xsl:if>
    <xsl:if test="$name = 'VoiceOverTouchSpeakingRate' or $name = 'QuickSpeakRate' or $name = 'MasterStereoBalance'">
      <xsl:if test="$node/@margin">
        <xsl:text>誤差許容範囲</xsl:text>
        <xsl:value-of select="number($node/@margin) *10"/>
        <xsl:text>%</xsl:text>
      </xsl:if>
    </xsl:if>
    <xsl:text>,</xsl:text>
    <xsl:choose>
      <xsl:when test="contains($node/@rule, 'Front')">
        <xsl:text>前方一致</xsl:text>
      </xsl:when>
      <xsl:when test="not(contains($node/@rule, 'Front')) and contains($node/@rule, 'Rear')">
        <xsl:text>後方一致</xsl:text>
      </xsl:when>
    </xsl:choose>
    <xsl:text>,"</xsl:text>
    <xsl:value-of select="$node/@compare"/>
    <xsl:text>""",</xsl:text>
    <xsl:if test="$node/@unique = 'on'">
      <xsl:text>○</xsl:text>
    </xsl:if>
    <xsl:text>,</xsl:text>
  </xsl:template>
  <xsl:template name="NoSetting"></xsl:template>

  <xsl:template name="MailBoxPlaces">
    <xsl:param name="value"/>
    <xsl:call-template name="MailBoxPlace">
      <xsl:with-param name="value" select="$value"/>
    </xsl:call-template>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$value"/>
    </xsl:call-template>
    <xsl:call-template name="MailBoxPlace">
      <xsl:with-param name="value" select="$value/@master"/>
    </xsl:call-template>
  </xsl:template>


  <xsl:template name="BookMark">
    <xsl:param name="bm"/>
    <xsl:if test="Folder and (First = 'true' or Empty = 'true')">
      <xsl:text>&#x20;&#x0a;</xsl:text>
      <xsl:text>,,フォルダ名,,,,"=""</xsl:text>
      <xsl:choose>
        <xsl:when test="Special = 'true' and Folder = 'BookmarksBar'">
          <xsl:text>ブックマークバー</xsl:text>
        </xsl:when>
        <xsl:when test="Special = 'true' and Folder = 'com.apple.ReadingList'">
          <xsl:text>リーディングリスト</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="Folder"/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:text>""",</xsl:text>
      <xsl:call-template name="sign">
        <xsl:with-param name="this" select="Folder"/>
      </xsl:call-template>
      <xsl:text>"=""</xsl:text>
      <xsl:choose>
        <xsl:when test="Special = 'true' and Folder/@master = 'BookmarksBar'">
          <xsl:text>ブックマークバー</xsl:text>
        </xsl:when>
        <xsl:when test="Special = 'true' and Folder/@master = 'com.apple.ReadingList'">
          <xsl:text>リーディングリスト</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="Folder/@master"/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:text>"""</xsl:text>
    </xsl:if>
    <xsl:if test="URL and Title">
      <xsl:text>&#x20;&#x0a;</xsl:text>
      <xsl:text>,,</xsl:text>
      <xsl:if test="Folder">
        <xsl:text>,</xsl:text>
      </xsl:if>
      <xsl:text>ブックマーク,タイトル,,</xsl:text>
      <xsl:if test="not(Folder)">
        <xsl:text>,</xsl:text>
      </xsl:if>
      <xsl:call-template name="text">
        <xsl:with-param name="this" select="Title"/>
      </xsl:call-template>
      <xsl:text>&#x20;&#x0a;</xsl:text>
      <xsl:text>,,</xsl:text>
      <xsl:if test="Folder">
        <xsl:text>,</xsl:text>
      </xsl:if>
      <xsl:text>,URL,,</xsl:text>
      <xsl:if test="not(Folder)">
        <xsl:text>,</xsl:text>
      </xsl:if>
      <xsl:call-template name="text">
        <xsl:with-param name="this" select="URL"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>



  <xsl:template name="maxInactivity">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="$this/text()='0'">
        <xsl:text>しない</xsl:text>
      </xsl:when>
      <xsl:when test="$this/text()=''">
        <xsl:text>しない</xsl:text>
      </xsl:when>
      <xsl:when test="$this/text()='2147483647'">
        <xsl:text>しない</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="number($this) div 60"/>
        <xsl:text>分</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <xsl:choose>
      <xsl:when test="not($this/@master)"></xsl:when>
      <xsl:when test="$this/@master='0'">
        <xsl:text>しない</xsl:text>
      </xsl:when>
      <xsl:when test="$this/@master=''">
        <xsl:text>しない</xsl:text>
      </xsl:when>
      <xsl:when test="$this/text()='2147483647'">
        <xsl:text>しない</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="number($this/@master) div 60"/>
        <xsl:text>分</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="maxGracePeriod">
    <xsl:param name="this"/>
    <xsl:call-template name="min2hour">
      <xsl:with-param name="min" select="$this/text()"/>
    </xsl:call-template>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <xsl:if test="$this/@master">
      <xsl:call-template name="min2hour">
        <xsl:with-param name="min" select="$this/@master"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="allowExplicitContent">
    <xsl:param name="this"/>
    <xsl:choose>
      <xsl:when test="$this/text()='true'">
        <xsl:text>不適切な内容</xsl:text>
      </xsl:when>
      <xsl:when test="not($this)"></xsl:when>
      <xsl:otherwise>
        <xsl:text>不適切な内容を含まない</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <xsl:choose>
      <xsl:when test="$this/@master='true'">
        <xsl:text>不適切な内容</xsl:text>
      </xsl:when>
      <xsl:when test="not($this/@master)"></xsl:when>
      <xsl:otherwise>
        <xsl:text>不適切な内容を含まない</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="SBParentalControlsCapabilities">
    <xsl:param name="capability"/>
    <xsl:choose>
      <xsl:when test="$capability = 'true'">
        <xsl:text>変更を許可しない</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>変更を許可</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text>,</xsl:text>
    <xsl:call-template name ="sign">
      <xsl:with-param name="this" select="$capability"/>
    </xsl:call-template>
    <xsl:choose>
      <xsl:when test="not($capability/@master)"></xsl:when>
      <xsl:when test="$capability/@master = 'true'">
        <xsl:text>変更を許可しない</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>変更を許可</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="KeyBoard">
    <xsl:param name="this"/>
    <xsl:text>,,</xsl:text>
    <xsl:if test="position() = 1">
      <xsl:text>キーボード</xsl:text>
    </xsl:if>
    <xsl:text>,キーボード</xsl:text>
    <xsl:value-of select="position()"/>
    <xsl:text>,,,,</xsl:text>
    <xsl:call-template name="sign" >
      <xsl:with-param name="this" select="$this" />
    </xsl:call-template>
    <xsl:text>&#x20;&#x0a;</xsl:text>
    <xsl:text>,,,,言語,,</xsl:text>
    <xsl:if test="contains(./text(), '@')">
      <xsl:call-template name="language" >
        <xsl:with-param name="countrycode" select="substring-before($this/text(),'@')"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="not(contains(./text(), '@'))">
      <xsl:call-template name="language" >
        <xsl:with-param name="countrycode" select="$this/text()"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:text>,,</xsl:text>
    <xsl:if test="contains(./@master, '@')">
      <xsl:call-template name="language" >
        <xsl:with-param name="countrycode" select="substring-before($this/@master,'@')"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="not(contains(./@master, '@'))">
      <xsl:call-template name="language" >
        <xsl:with-param name="countrycode" select="$this/@master"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:text>,</xsl:text>
    <xsl:text>&#x20;&#x0a;</xsl:text>
    <xsl:if test="not(starts-with($this/text(),'emoji@')) and not(starts-with($this/@master,'emoji@'))">
      <xsl:text>,,,,キーボード配列,,</xsl:text>
      <xsl:call-template name="keyboard_sw" >
        <xsl:with-param name="key" select="$this"/>
      </xsl:call-template>
      <xsl:text>,,</xsl:text>
      <xsl:call-template name="keyboard_sw" >
        <xsl:with-param name="key" select="$this/@master"/>
      </xsl:call-template>
      <xsl:text>,</xsl:text>
      <xsl:text>&#x20;&#x0a;</xsl:text>
      <!--<xsl:if test="contains($this/text(),'hw=') or contains($this/@master,'hw=')">
        <xsl:text>,,,,ハードウェアキーボード配列,,</xsl:text>
        <xsl:call-template name="keyboard_hw" >
          <xsl:with-param name="key" select="$this"/>
        </xsl:call-template>
        <xsl:text>,,</xsl:text>
        <xsl:call-template name="keyboard_hw" >
          <xsl:with-param name="key" select="$this/@master"/>
        </xsl:call-template>
        <xsl:text>,</xsl:text>
        <xsl:text>&#x20;&#x0a;</xsl:text>
      </xsl:if>-->
      <xsl:if test="starts-with($this/text(),'ja_JP-Kana') or starts-with($this/@master,'ja_JP-Kana')">
        <xsl:text>,,,,オプション,,</xsl:text>
        <xsl:if test="starts-with($this/text(),'ja_JP-Kana')">
        <xsl:if test="contains($this/text(),'-Flick')">
          <xsl:text>フリックのみ </xsl:text>
        </xsl:if>
        <xsl:if test="not(contains($this/text(),'-RTL'))">
          <xsl:text>あ行が左</xsl:text>
        </xsl:if>
        </xsl:if>
        <xsl:text>,,</xsl:text>
        <xsl:if test="starts-with($this/@master,'ja_JP-Kana')">
          <xsl:if test="contains($this/@master,'-Flick')">
            <xsl:text>フリックのみ </xsl:text>
          </xsl:if>
          <xsl:if test="not(contains($this/@master,'-RTL'))">
            <xsl:text>あ行が左</xsl:text>
          </xsl:if>
        </xsl:if>
        <xsl:text>,</xsl:text>
        <xsl:text>&#x20;&#x0a;</xsl:text>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <xsl:template name="Margin">
    <xsl:param name="margin"/>
    <xsl:text>誤差許容範囲:</xsl:text>
    <xsl:value-of select="number($margin) * 100"/>
    <xsl:text>%</xsl:text>
  </xsl:template>
  
  <xsl:template name="settingtable">
    <xsl:param name="id"/>
    <xsl:param name="title1"/>
    <xsl:param name="title2"/>
    <xsl:param name="title3"/>
    <xsl:param name="title4"/>
    <xsl:param name="title5"/>
    <xsl:param name="title6"/>
    <xsl:param name="template"/>
    <xsl:param name="param1"/>
    <xsl:param name="param2"/>
    <xsl:param name="param3"/>
    <xsl:param name="param4"/>
    <xsl:param name="valueNode"/>
    <xsl:param name="value"/>
    <xsl:param name="sign"/>
    <xsl:param name="rowspan"/>
    <xsl:param name="nosign"/>
    <xsl:param name="mastervalue"/>
    <xsl:param name="create"/>


        <xsl:value-of select="$title1"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="$title2"/>
    <xsl:text>,</xsl:text>
        <xsl:value-of select="$title3"/>
    <xsl:text>,</xsl:text>
    <xsl:value-of select="$title4"/>
    <xsl:text>,</xsl:text>
        <xsl:value-of select="$title5"/>
    <xsl:text>,</xsl:text>
        <xsl:value-of select="$title6"/>
    <xsl:text>,</xsl:text>

      <xsl:if test="not($template)">
          <xsl:copy-of select="$value"/>
        <xsl:text>,</xsl:text>
        <xsl:choose>
          <xsl:when test="$nosign">
          </xsl:when>
          <xsl:when test="not($sign)">
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$sign != ''">
              <xsl:copy-of select="$sign"/>
            <xsl:text>,</xsl:text>
          </xsl:when>
        </xsl:choose>
          <xsl:if test="$mastervalue != ''">
            <xsl:copy-of select="$mastervalue"/>
          </xsl:if>
          <xsl:if test="not($mastervalue)">
            <xsl:value-of select="$value/@master"/>
          </xsl:if>
        <xsl:text>,</xsl:text>
      </xsl:if>
      <xsl:if test="$template">
        <xsl:choose>
          <xsl:when test="$template = 'text'">
            <xsl:call-template name="text">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'defaultOff'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="defaultOff">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="defaultOff">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'defaultOn'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="defaultOn">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="defaultOn">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'OnOff'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="OnOff">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="OnOff">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'maxInactivity'">
            <xsl:call-template name="maxInactivity">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'countryname'">
            <xsl:call-template name="countryname">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'allowExplicitContent'">
            <xsl:call-template name="allowExplicitContent">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'maxGracePeriod'">
            <xsl:call-template name="maxGracePeriod">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'SBParentalControlsCapabilities'">
            <xsl:call-template name="SBParentalControlsCapabilities">
              <xsl:with-param name="capability" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization'">
            <xsl:call-template name="Authorization">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization2'">
            <xsl:call-template name="Authorization2">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization3'">
            <xsl:call-template name="Authorization3">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'specifiedefSuffix'">
            <xsl:call-template name="specifiedefSuffix">
              <xsl:with-param name="this" select="$valueNode"/>
              <xsl:with-param name="default" select="$param1"/>
              <xsl:with-param name="suffix" select="$param2"/>
              <xsl:with-param name="except" select="$param3"/>
              <xsl:with-param name="exdesc" select="$param4"/>
            </xsl:call-template>
          </xsl:when>
        </xsl:choose>
      </xsl:if>
    <xsl:text>,</xsl:text>
    <xsl:text>&#x20;&#x0a;</xsl:text>
  </xsl:template>
  
</xsl:stylesheet>