<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
    xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">
  <xsl:output method="html" media-type="text/html" encoding="UTF-8"/>
  <xsl:param name="uuid" select="/Root/DeviceName" />
  <xsl:param name="count" select="/Root/DeviceName" />

  <xsl:variable name="MajorVersion" select="number(substring-before(/RESULT/ProductVersion, '.'))"/>
  
  <xsl:variable name="defsetting" select="document('conf:default.xml')/Root"/>
  <!--<xsl:variable name="mastersetting" select="document('conf:master.xml')/Root"/>-->
  
  <xsl:include href="Function.xslt"/>
  <xsl:include href="diff/Section001.xslt"/>
  <xsl:include href="diff/Section002.xslt"/>
  <xsl:include href="diff/Section003.xslt"/>
  <xsl:include href="diff/SectionSiri.xslt"/>
  <xsl:include href="diff/SectionSpotlight.xslt"/>
  <xsl:include href="diff/SectionVoiceOver.xslt"/>
  <xsl:include href="diff/SectionAccessibility01.xslt"/>
  <xsl:include href="diff/SectionAccessibility02.xslt"/>
  <xsl:include href="diff/SectioniPad.xslt"/>
  <xsl:include href="diff/Section004.xslt"/>
  <xsl:include href="diff/SectionRestrict.xslt"/>
  <xsl:include href="diff/SectionLocationService.xslt"/>
  <xsl:include href="diff/SectionRestrict2.xslt"/>
  <xsl:include href="diff/SectionLocale.xslt"/>
  <xsl:include href="diff/SectionProfile.xslt"/>
  <xsl:include href="diff/SectionScreen.xslt"/>
  <xsl:include href="diff/SectionPasscode.xslt"/>
  <xsl:include href="diff/SectionPrivacy.xslt"/>
  <xsl:include href="diff/SectionStore.xslt"/>
  <xsl:include href="diff/SectioniCloud.xslt"/>
  <xsl:include href="diff/SectionAccount.xslt"/>
  <xsl:include href="diff/SectionMail.xslt"/>
  <xsl:include href="diff/SectionScreentime.xslt"/>
  <xsl:include href="diff/SectionControlCenter.xslt"/>
  <xsl:include href="diff/SectionBattery.xslt"/>
  <xsl:include href="diff/SectionSOS.xslt"/>
  <xsl:include href="diff/SectionWallet.xslt"/>
  
  <xsl:template match="/">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="RESULT">
    <table class="console" id="mastertable">
      <tr id="tableheader">
        <th class="t_top" colspan="6">設定項目</th>
        <th class="t_top02" style="width:220px">デバイスの設定値</th>
        <th class="t_top02" style="width:40px">差異</th>
        <th class="t_top" style="width:220px">マスター設定値</th>
      </tr>
      <xsl:call-template name="setting"/>
    </table>
  </xsl:template>
  <xsl:template name="setting">

    <xsl:call-template name="Section001"/>
    <xsl:if test="$MajorVersion &lt;= 11">
      <xsl:call-template name="SectionControlCenter"/>
    </xsl:if>
    <xsl:if test="$MajorVersion &gt;= 12">
      <xsl:call-template name="SectionScreentime"/>
      <xsl:call-template name="SectionLocationService">
        <xsl:with-param name="privacy" select="0"/>
      </xsl:call-template>


      <xsl:call-template name="SectionRestrict2">
        <xsl:with-param name="gamecenter" select="0"/>
      </xsl:call-template>
    </xsl:if>
    
    <!--一般 情報-->
    <xsl:call-template name="Section002"/>
    
    <xsl:if test="$MajorVersion &gt;= 7 and $MajorVersion &lt;= 9">
      <xsl:call-template name="SectionSiri"/>
    </xsl:if>
    <xsl:if test="$MajorVersion &lt;= 10">
      <xsl:call-template name="SectionSpotlight"/>
    </xsl:if>
    
    <xsl:call-template name="Section003"/>

    <xsl:if test="$MajorVersion &lt; 13">
      <xsl:call-template name="SectionVoiceOver"/>

      <xsl:call-template name="SectionAccessibility01"/>
      <xsl:call-template name="SectionAccessibility02"/>
    </xsl:if>

    <!--iPad用-->
    <xsl:if test="$MajorVersion &gt;= 8 and /RESULT/DeviceClass = 'iPad'">
      <xsl:call-template name="SectioniPad"/>
    </xsl:if>

    <xsl:call-template name="Section004"/>
    <!--機能制限-->
    <xsl:if test="$MajorVersion &lt; 12">
    <xsl:call-template name="SectionRestrict"/>
    <xsl:if test="/RESULT/SBParentalControlsEnabled = 'true'">
      <xsl:call-template name="SectionLocationService"/>
    </xsl:if>
    <xsl:call-template name="SectionRestrict2"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion = 7 and /RESULT/DeviceClass = 'iPad'">
      <xsl:call-template name="SectioniPad"/>
    </xsl:if>
    <!--日付と時刻-->
    <xsl:call-template name="SectionLocale"/>
    <!--プロファイル-->
    <xsl:call-template name="SectionProfile"/>

    <xsl:if test="$MajorVersion &gt;= 12">
      <xsl:call-template name="SectionControlCenter"/>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 9">
      <xsl:call-template name="SectionScreen"/>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 13">
      <xsl:call-template name="SectionVoiceOver"/>

      <xsl:call-template name="SectionAccessibility01"/>
      <xsl:call-template name="SectionAccessibility02"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionSiri"/>
    </xsl:if>
    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="SectionSpotlight"/>
    </xsl:if>


    <xsl:call-template name="SectionPasscode"/>

    <xsl:if test="$MajorVersion &gt;= 11">
      <xsl:call-template name="SectionSOS"/>
      <xsl:call-template name="SectionBattery"/>
    </xsl:if>
    
    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionLocationService">
        <xsl:with-param name="privacy" select="1"/>
      </xsl:call-template>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionPrivacy"/>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 10">
      <xsl:call-template name="SectionStore"/>
    </xsl:if>

    <xsl:call-template name="SectionWallet"/>
    <xsl:call-template name="SectionAccount"/>
    
    <tr>
      <td class="t_line05">
        <xsl:text>アプリケーション</xsl:text>
      </td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line04"></td>
      <td class="t_line04"></td>
      <td class="t_line04">
        <xsl:if test="Applications/Application[@order = 'true']">
          <xsl:text>[順序をチェックする]</xsl:text>
        </xsl:if>
        <xsl:if test="Applications/Application[@order = 'false']">
          <xsl:text>[順序をチェックしない]</xsl:text>
        </xsl:if>
      </td>
    </tr>
    <xsl:for-each select="Applications/Application">
      <xsl:if  test="Page and NewPage">
        <tr>
          <td class="t_line05">
            <xsl:choose>
              <xsl:when test="Page = '-1'">
                <xsl:text>ドック</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>ホーム画面</xsl:text><xsl:value-of select="number(Page) + 1"/>
              </xsl:otherwise>
            </xsl:choose>
          </td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line04"></td>
          <td class="t_line04"></td>
          <td class="t_line04"></td>
        </tr>
      </xsl:if>
      <xsl:if test="Folder and FirstChildren = 'true'">
        <tr>
          <xsl:attribute name="id">
            <xsl:text>Applications/Application_</xsl:text><xsl:value-of select="position()"/>/Folder
          </xsl:attribute>
          <td class="t_line05"></td>
          <td class="t_line05">フォルダ名</td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line04">
            <xsl:value-of select="Folder" />
          </td>
          <xsl:call-template name="sign">
            <xsl:with-param name="this" select="Folder"/>
          </xsl:call-template>
          <td class="t_line04">
            <xsl:value-of select="Folder/@master" />
          </td>
        </tr>
      </xsl:if>
      <xsl:choose>
        <xsl:when test="URL and Title">
          <tr>
            <xsl:attribute name="id">
              <xsl:text>Applications/Application_</xsl:text><xsl:value-of select="position()"/>/Title
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05">
              <xsl:text>アプリケーション</xsl:text><xsl:value-of select="position()"/>
            </td>
            <td class="t_line05">
              <xsl:text>名前</xsl:text>
            </td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line04">
              <xsl:choose>
                <xsl:when test="DefaultApp = 'true'">
                  <xsl:call-template name="DefaultApp">
                    <xsl:with-param name="appID" select="CFBundleIdentifier"/>
                    <xsl:with-param name="device" select="/RESULT/DeviceClass"/>
                  </xsl:call-template>
                </xsl:when>
                <xsl:when test="Title != ''">
                  <xsl:value-of select="Title" />
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="CFBundleDisplayName" />
                </xsl:otherwise>
              </xsl:choose>

            </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="Title"/>
            </xsl:call-template>
            <td class="t_line04">
              <xsl:choose>
                <xsl:when test="DefaultApp/@master = 'true'">
                  <xsl:call-template name="DefaultApp">
                    <xsl:with-param name="appID" select="CFBundleIdentifier/@master"/>
                    <xsl:with-param name="device" select="/RESULT/DeviceClass/@master"/>
                  </xsl:call-template>
                </xsl:when>
                <xsl:when test="Title/@master != ''">
                  <xsl:value-of select="Title/@master" />
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="CFBundleDisplayName/@master" />
                </xsl:otherwise>
              </xsl:choose>
              <xsl:if test="Title/@part">
                <xsl:choose>
                  <xsl:when test="Title/@part = 'front'">
                    <xsl:text>[前方一致]</xsl:text>
                  </xsl:when>
                  <xsl:when test="Title/@part = 'rear'">
                    <xsl:text>[後方一致]</xsl:text>
                  </xsl:when>
                </xsl:choose>
              </xsl:if>
            </td>

          </tr>
          <tr>
            <xsl:attribute name="id">
              <xsl:text>Applications/Application_</xsl:text><xsl:value-of select="position()"/>/URL
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05"></td>
            <td class="t_line05">
              <xsl:text>URL</xsl:text>
            </td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line04 wordbreak">
              <xsl:value-of select="URL" />
            </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="URL"/>
            </xsl:call-template>
            <td class="t_line04 wordbreak">
              <xsl:value-of select="URL/@master" />
              <xsl:if test="URL/@part">
                <xsl:choose>
                  <xsl:when test="URL/@part = 'front'">
                    <xsl:text>[前方一致]</xsl:text>
                  </xsl:when>
                  <xsl:when test="URL/@part = 'rear'">
                    <xsl:text>[後方一致]</xsl:text>
                  </xsl:when>
                </xsl:choose>
              </xsl:if>
            </td>
          </tr>
        </xsl:when>
        <xsl:when test="URL and not(Title)">
          <tr>
            <xsl:attribute name="id">
              <xsl:text>Applications/Application_</xsl:text><xsl:value-of select="position()"/>/URL
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05">
              <xsl:text>アプリケーション</xsl:text><xsl:value-of select="position()"/>
            </td>
            <td class="t_line05">
              <xsl:text>URL</xsl:text>
            </td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line04 wordbreak">
              <xsl:value-of select="URL" />
            </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="URL"/>
            </xsl:call-template>
            <td class="t_line04 wordbreak">
              <xsl:value-of select="URL/@master" />
              <xsl:if test="URL/@part">
                <xsl:choose>
                  <xsl:when test="URL/@part = 'front'">
                    <xsl:text>[前方一致]</xsl:text>
                  </xsl:when>
                  <xsl:when test="URL/@part = 'rear'">
                    <xsl:text>[後方一致]</xsl:text>
                  </xsl:when>
                </xsl:choose>
              </xsl:if>
            </td>
          </tr>
        </xsl:when>
        <xsl:when test="not(URL) and Title">
          <tr>
            <xsl:attribute name="id">
              <xsl:text>Applications/Application_</xsl:text><xsl:value-of select="position()"/>/Title
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05">
              <xsl:text>アプリケーション</xsl:text><xsl:value-of select="position()"/>
            </td>
            <td class="t_line05">
              <xsl:text>名前</xsl:text>
            </td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line04">
              <xsl:choose>
                <xsl:when test="DefaultApp = 'true'">
                  <xsl:call-template name="DefaultApp">
                    <xsl:with-param name="appID" select="CFBundleIdentifier"/>
                    <xsl:with-param name="device" select="/RESULT/DeviceClass"/>
                  </xsl:call-template>
                </xsl:when>
                <xsl:when test="Title != ''">
                  <xsl:value-of select="Title" />
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="CFBundleDisplayName" />
                </xsl:otherwise>
              </xsl:choose>

            </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="Title"/>
            </xsl:call-template>
            <td class="t_line04">
              <xsl:choose>
                <xsl:when test="DefaultApp/@master = 'true'">
                  <xsl:call-template name="DefaultApp">
                    <xsl:with-param name="appID" select="CFBundleIdentifier/@master"/>
                    <xsl:with-param name="device" select="/RESULT/DeviceClass/@master"/>
                  </xsl:call-template>
                </xsl:when>
                <xsl:when test="Title/@master != ''">
                  <xsl:value-of select="Title/@master" />
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="CFBundleDisplayName/@master" />
                </xsl:otherwise>
              </xsl:choose>
              <xsl:if test="Title/@part">
                <xsl:choose>
                  <xsl:when test="Title/@part = 'front'">
                    <xsl:text>[前方一致]</xsl:text>
                  </xsl:when>
                  <xsl:when test="Title/@part = 'rear'">
                    <xsl:text>[後方一致]</xsl:text>
                  </xsl:when>
                </xsl:choose>
              </xsl:if>
            </td>
          </tr>
        </xsl:when>
        <xsl:when test="DefaultApp = 'true'">
          <tr>
            <xsl:attribute name="id">Applications/Application_<xsl:value-of select="position()"/>/DefaultApp
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05">
              <xsl:text>アプリケーション</xsl:text><xsl:value-of select="position()"/>
            </td>
            <td class="t_line05">
              <xsl:text>名前</xsl:text>
            </td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line04">
                  <xsl:call-template name="DefaultApp">
                    <xsl:with-param name="appID" select="CFBundleIdentifier"/>
                    <xsl:with-param name="device" select="/RESULT/DeviceClass"/>
                  </xsl:call-template>
            </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="CFBundleIdentifier"/>
            </xsl:call-template>
            <td class="t_line04">
                  <xsl:call-template name="DefaultApp">
                    <xsl:with-param name="appID" select="CFBundleIdentifier/@master"/>
                    <xsl:with-param name="device" select="/RESULT/DeviceClass/@master"/>
                  </xsl:call-template>
            </td>
          </tr>
          
        </xsl:when>
        <xsl:otherwise>
          <tr>
            <xsl:attribute name="id">
              <xsl:text>Applications/Application_</xsl:text><xsl:value-of select="position()"/>/CFBundleDisplayName
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05">
              <xsl:text>アプリケーション</xsl:text><xsl:value-of select="position()"/>
            </td>
            <td class="t_line05">
              <xsl:text>名前</xsl:text>
            </td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line04">
                  <xsl:value-of select="CFBundleDisplayName" />
            </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="CFBundleDisplayName"/>
            </xsl:call-template>
            <td class="t_line04">
                <xsl:value-of select="CFBundleDisplayName/@master" />
            </td>
          </tr>
          <tr>
            <xsl:attribute name="id">
              <xsl:text>Applications/Application_</xsl:text><xsl:value-of select="position()"/>/CFBundleVersion
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05"></td>
            <td class="t_line05">バージョン</td>
            <td class="t_line05">リリースバージョン</td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line04">
              <xsl:value-of select="CFBundleVersion" />
            </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="CFBundleVersion"/>
            </xsl:call-template>
            <td class="t_line04">
              <xsl:value-of select="CFBundleVersion/@master" />
            </td>
          </tr>
          <tr>
            <xsl:attribute name="id">
              <xsl:text>Applications/Application_</xsl:text><xsl:value-of select="position()"/>/CFBundleShortVersionString
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <td class="t_line05">ビルドバージョン</td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line04">
              <xsl:value-of select="CFBundleShortVersionString" />
            </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="CFBundleShortVersionString"/>
            </xsl:call-template>
            <td class="t_line04">
              <xsl:value-of select="CFBundleShortVersionString/@master" />
            </td>
          </tr>
          <tr>
            <xsl:attribute name="id">
              <xsl:text>Applications_</xsl:text><xsl:value-of select="position()"/>_CFBundleIdentifier
            </xsl:attribute>
            <td class="t_line05"></td>
            <xsl:if test="Folder">
              <td class="t_line05"></td>
            </xsl:if>
            <td class="t_line05"></td>
            <td class="t_line05">識別子</td>
            <td class="t_line05"></td>
            <td class="t_line05"></td>
            <xsl:if test="not(Folder)">
              <td class="t_line05"></td>
            </xsl:if>
            <xsl:call-template name="text">
              <xsl:with-param name="this" select="CFBundleIdentifier"/>
            </xsl:call-template>
          </tr>
          
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>

    <tr>
      <td class="t_line05">
        <xsl:text>Safari</xsl:text>
      </td>
      <td class="t_line05">ブックマーク</td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line04"></td>
      <td class="t_line04"></td>
      <td class="t_line04"></td>
    </tr>
    <xsl:for-each select="Safari/BookMarks/BookMark">
      <xsl:if test="not(Folder) or (Folder and Folder != 'com.apple.ReadingList' and Folder != 'com.apple.WebFilterWhiteList')">
        <xsl:if test="Folder and (First = 'true' or Empty = 'true')">
        <tr>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05">フォルダ名</td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line04 wordbreak">
            <xsl:choose>
              <xsl:when test="Special = 'true' and Folder = 'BookmarksBar'">
                <xsl:text>お気に入り</xsl:text>
              </xsl:when>
              <xsl:when test="Special = 'true' and Folder = 'com.apple.ReadingList'">
                <xsl:text>リーディングリスト</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="Folder"/>
              </xsl:otherwise>
            </xsl:choose>
          </td>
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="Folder"/>
            </xsl:call-template>
          <td class="t_line04">
            <xsl:choose>
              <xsl:when test="Special = 'true' and Folder/@master = 'BookmarksBar'">
                <xsl:text>お気に入り</xsl:text>
              </xsl:when>
              <xsl:when test="Special = 'true' and Folder/@master = 'com.apple.ReadingList'">
                <xsl:text>リーディングリスト</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="Folder/@master"/>
              </xsl:otherwise>
            </xsl:choose>
          </td>
        </tr>
      </xsl:if>

      <xsl:if test="URL and Title">
        <tr>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05">
            <xsl:text>ブックマーク</xsl:text>
          </td>
          <td class="t_line05">
            <xsl:text>タイトル</xsl:text>
          </td>
          <td class="t_line05"></td>

          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <xsl:call-template name="text">
            <xsl:with-param name="this" select="Title"/>
          </xsl:call-template>
        </tr>
        <tr>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <xsl:if test="Folder">
            <td class="t_line05"></td>
          </xsl:if>
          <td class="t_line05"></td>
          <td class="t_line05">
            <xsl:text>URL</xsl:text>
          </td>
          <td class="t_line05"></td>
          <xsl:if test="not(Folder)">
            <td class="t_line05"></td>
          </xsl:if>
          <xsl:call-template name="text">
            <xsl:with-param name="this" select="URL"/>
          </xsl:call-template>
        </tr>
      </xsl:if>
      </xsl:if>
    
    </xsl:for-each>

    <tr>
      <td class="t_line05"></td>
      <td class="t_line05">閲覧履歴</td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line04">
        <xsl:choose>
          <xsl:when test="Safari/HasHistory = 'true'">
            <xsl:text>あり</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>なし</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </td>
      <xsl:call-template name="sign">
        <xsl:with-param name="this" select="Safari/HasHistory"/>
      </xsl:call-template>
      <td class="t_line04">
        <xsl:if test="Safari/HasHistory/@match">
          <xsl:text>[閲覧履歴なし]</xsl:text>
        </xsl:if>
      </td>
      
    </tr>
    
    
    
  </xsl:template>
  
  
  <!--設定値がない時空白になる-->
  <xsl:template name="OnOff">
    <xsl:param name="bool"/>
    <xsl:param name="label-on">オン</xsl:param>
    <xsl:param name="label-off">オフ</xsl:param>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$bool = 'true'">
          <xsl:value-of select="$label-on"/>
        </xsl:when>
        <xsl:when test="$bool = 'false'">
          <xsl:value-of select="$label-off"/>
        </xsl:when>
      </xsl:choose>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$bool"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="not($bool/@master)">
          
        </xsl:when>
        <xsl:when test="$bool/@master = 'true'">
          <xsl:value-of select="$label-on"/>
        </xsl:when>
        <xsl:when test="$bool/@master = 'false'">
          <xsl:value-of select="$label-off"/>
        </xsl:when>
      </xsl:choose>
    </td>
  </xsl:template>
  
  <!--設定値がない時オフになる-->
  <xsl:template name="defaultOff">
    <xsl:param name="bool"/>
    <xsl:param name="label-on">オン</xsl:param>
    <xsl:param name="label-off">オフ</xsl:param>
    <xsl:param name="empty">false</xsl:param>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$bool = 'true' or $bool = '1'">
          <xsl:value-of select="$label-on"/>
        </xsl:when>
        <xsl:when test="not($bool) or $empty = 'true'">
          
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$label-off"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$bool"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$bool/@master = 'true' or $bool/@master = '1'">
          <xsl:value-of select="$label-on"/>
        </xsl:when>
        <xsl:when test="not($bool/@master)">

        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$label-off"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>
  
  <!--設定値がない時オンになる-->
  <xsl:template name="defaultOn">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-on">オン</xsl:param>
    <xsl:param name="label-off">オフ</xsl:param>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$bool = 'false'">
          <xsl:value-of select="$label-off"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$label-on"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$bool"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$bool/@master = 'false'">
          <xsl:value-of select="$label-off"/>
        </xsl:when>
        <xsl:when test="not($bool/@master)">

        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$label-on"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <xsl:template name="sign">
    <xsl:param name="this"/>
    <td class="t_line06">
      <xsl:choose>
        <xsl:when test="$this/@unique = 'false'">
          <img src="images/ball_red.gif" width="15" height="15" />
          <br>重複</br>
        </xsl:when>
        <xsl:when test="not($this/@match)">
          <img src="images/ball_gray.gif" width="15" height="15" />
          <xsl:value-of select="$this/@match"/>
        </xsl:when>
        <xsl:when test="$this/@match = 'true'">
          <img src="images/ball_green.gif" width="15" height="15" />
        </xsl:when>
        <xsl:when test="$this/@match = 'false'">
          <img src="images/ball_red.gif" width="15" height="15" />
        </xsl:when>
        <xsl:when test="$this/@match = 'extra'">
          <img src="images/ball_red.gif" width="15" height="15" />
        </xsl:when>
        <xsl:when test="$this/@match = 'short'">
          <img src="images/ball_red.gif" width="15" height="15" />
        </xsl:when>
      </xsl:choose>
    </td>
  </xsl:template>

  
  <xsl:template name="text">
    <xsl:param name="this"/>
    <td class="t_line04 no_img wordbreak">
      
      <xsl:value-of select="$this/text()"/>
    </td>
    <td class="t_line06">
      <xsl:choose>
        <xsl:when test="$this/@unique = 'false'">
          <img src="images/ball_red.gif" width="15" height="15" /><br>重複</br>
        </xsl:when>
        <xsl:when test="$this/@match = 'true' and ( not($this/@unique) or $this/@unique = 'true')">
          <img src="images/ball_green.gif" width="15" height="15" />
          <xsl:if test="$this/@unique = 'true'">
            <br>重複なし</br>
          </xsl:if>
        </xsl:when>
        <xsl:when test="not($this/@match) and $this/@unique = 'true'">
          <img src="images/ball_green.gif" width="15" height="15" />
          <br>重複なし</br>
        </xsl:when>
        <xsl:when test="$this/@match = 'false'">
          <img src="images/ball_red.gif" width="15" height="15" />
        </xsl:when>
        <xsl:when test="not($this/@match)">
          <img src="images/ball_gray.gif" width="15" height="15" />
        </xsl:when>
        <xsl:when test="$this/@match = 'extra'">
          <img src="images/ball_red.gif" width="15" height="15" />
        </xsl:when>
        <xsl:when test="$this/@match = 'short'">
          <img src="images/ball_red.gif" width="15" height="15" />
        </xsl:when>
      </xsl:choose>
    </td>
    <td class="t_line04 no_img wordbreak">
      <xsl:value-of select="$this/@master"/>
      <xsl:if test="$this/@part">
        <xsl:choose>
          <xsl:when test="$this/@part = 'front'">
            <xsl:text>[前方一致]</xsl:text>
          </xsl:when>
          <xsl:when test="$this/@part = 'rear'">
            <xsl:text>[後方一致]</xsl:text>
          </xsl:when>
        </xsl:choose>
      </xsl:if>
    </td>
  </xsl:template>

  <xsl:template name="maxInactivity">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$this/text()='0'">
          <xsl:text>なし</xsl:text>
        </xsl:when>
        <xsl:when test="$this/text()=''">
          <xsl:text>なし</xsl:text>
        </xsl:when>
        <xsl:when test="$this/text()='2147483647'">
          <xsl:text>なし</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="number($this) div 60"/>分
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="not($this/@master)">
          
        </xsl:when>
        <xsl:when test="$this/@master='0'">
          <xsl:text>しない</xsl:text>
        </xsl:when>
        <xsl:when test="$this/@master=''">
          <xsl:text>しない</xsl:text>
        </xsl:when>
        <xsl:when test="$this/text()='2147483647'">
          <xsl:text>しない</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="number($this/@master) div 60"/>分
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <xsl:template name="Authorization">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:call-template name="locationAuthorization">
        <xsl:with-param name="value" select="$this"/>
      </xsl:call-template>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:call-template name="locationAuthorization">
        <xsl:with-param name="value" select="$this/@master"/>
      </xsl:call-template>
    </td>
  </xsl:template>

  <xsl:template name="Authorization2">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:call-template name="locationAuthorization2">
        <xsl:with-param name="value" select="$this"/>
      </xsl:call-template>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:call-template name="locationAuthorization2">
        <xsl:with-param name="value" select="$this/@master"/>
      </xsl:call-template>
    </td>
  </xsl:template>

  <xsl:template name="Authorization3">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:call-template name="locationAuthorization3">
        <xsl:with-param name="value" select="$this"/>
      </xsl:call-template>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:call-template name="locationAuthorization3">
        <xsl:with-param name="value" select="$this/@master"/>
      </xsl:call-template>
    </td>
  </xsl:template>
  
  <xsl:template name="maxGracePeriod">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:call-template name="min2hour">
        <xsl:with-param name="min" select="$this/text()"/>
      </xsl:call-template>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:if test="$this/@master">
      <xsl:call-template name="min2hour">
        <xsl:with-param name="min" select="$this/@master"/>
      </xsl:call-template>
      </xsl:if>
    </td>
  </xsl:template>

  <xsl:template name="allowExplicitContent">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$this/text()='true'">
          <xsl:text>不適切な内容</xsl:text>
        </xsl:when>
        <xsl:when test="not($this)">

        </xsl:when>
        <xsl:otherwise>
          <xsl:text>不適切な内容を含まない</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$this/@master='true'">
          <xsl:text>不適切な内容</xsl:text>
        </xsl:when>
        <xsl:when test="not($this/@master)">

        </xsl:when>
        <xsl:otherwise>
          <xsl:text>不適切な内容を含まない</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <xsl:template name="SBParentalControlsCapabilities">
    <xsl:param name="capability"/>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$capability = 'true'">
          <xsl:text>変更を許可しない</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>変更を許可</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <xsl:call-template name ="sign">
      <xsl:with-param name="this" select="$capability"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="not($capability/@master)">
          
        </xsl:when>
        <xsl:when test="$capability/@master = 'true'">
          <xsl:text>変更を許可しない</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>変更を許可</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <xsl:template name="zeroIsOn">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$this/text()='0'">
          <xsl:text>オン</xsl:text>
        </xsl:when>
        <xsl:when test="not($this)">
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>オフ</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$this/@master='0'">
          <xsl:text>オン</xsl:text>
        </xsl:when>
        <xsl:when test="not($this/@master)">
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>オフ</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <xsl:template name="zeroIsOff">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$this/text()='0'">
          <xsl:text>オフ</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>オン</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$this/@master='0'">
          <xsl:text>オフ</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>オン</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <!--false時オンになる-->
  <xsl:template name="falseOn">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-false">オン</xsl:param>
    <xsl:param name="label-true">オフ</xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:value-of select="$label-false"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-true"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="TrueFalse">
    <xsl:param name="bool" select="1"/>
    <xsl:param name="label-true">オン</xsl:param>
    <xsl:param name="label-false">オフ</xsl:param>
    <xsl:param name="label-other"></xsl:param>
    <xsl:choose>
      <xsl:when test="$bool = 'true'">
        <xsl:value-of select="$label-true"/>
      </xsl:when>
      <xsl:when test="$bool = 'false'">
        <xsl:value-of select="$label-false"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$label-other"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
    <!--false時オンになる-->
  <xsl:template name="falseOndefaultOff">
    <xsl:param name="bool" select="1"/>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="$bool = 'true'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>オフ</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!--false時オンになる-->
  <xsl:template name="falseOndefaultOn">
    <xsl:param name="bool" select="1"/>
    <xsl:choose>
      <xsl:when test="$bool = 'false'">
        <xsl:text>オン</xsl:text>
      </xsl:when>
      <xsl:when test="$bool = 'true'">
        <xsl:text>オフ</xsl:text>
      </xsl:when>
      <xsl:when test="not($bool)">
        
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>オン</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <!--国名ISO 3166-1(レートの対象)-->
  <xsl:template name="countryname">
    <xsl:param name="this"/>
    <td class="t_line04 no_img">
      <xsl:call-template name="country">
        <xsl:with-param name="countrycode" select="$this/text()"/>
      </xsl:call-template>
    </td>
    <xsl:call-template name="sign">
      <xsl:with-param name="this" select="$this"/>
    </xsl:call-template>
    <td class="t_line04 no_img">
      <xsl:call-template name="country">
        <xsl:with-param name="countrycode" select="$this/@master"/>
      </xsl:call-template>
    </td>
  </xsl:template>

  <xsl:template name="SMTPAlternateIdentifiers">
    <xsl:param name="value"/>
    <td class="t_line04 no_img">
      <xsl:choose>
        <xsl:when test="$value=''">
          <xsl:text>なし</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$value"/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <xsl:template name="MailBoxPlaces">
    <xsl:param name="value"/>
  <td class="t_line04">
    <xsl:call-template name="MailBoxPlace">
      <xsl:with-param name="value" select="$value"/>
    </xsl:call-template>
  </td>
  <xsl:call-template name="sign">
    <xsl:with-param name="this" select="$value"/>
  </xsl:call-template>
  <td class="t_line04 no_img">
    <xsl:call-template name="MailBoxPlace">
      <xsl:with-param name="value" select="$value/@master"/>
    </xsl:call-template>
  </td>
  </xsl:template>


  <xsl:template name="defaultNo">
    <xsl:param name="this"/>
    <td class="t_line04">
      <xsl:choose>
        <xsl:when test="$this = 'true'">
          <xsl:text>はい</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>いいえ</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
      <xsl:call-template name="sign">
        <xsl:with-param name="this" select="$this"/>
      </xsl:call-template>
    <td class="t_line04">
      <xsl:choose>
        <xsl:when test="$this/@master = 'true'">
          <xsl:text>はい</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>いいえ</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </td>
    
  </xsl:template>

  <xsl:template name="specifiedefSuffix">
    <xsl:param name="this"/>
    <xsl:param name="default"/>
    <xsl:param name="suffix" />
    <xsl:param name="except" />
    <xsl:param name="exdesc" />
  <td class="t_line04">
    <xsl:choose>
      <xsl:when test="$except and $this = $except">
        <xsl:value-of select="$exdesc"/>
      </xsl:when>
      <xsl:when test="$this = ''">
        <xsl:value-of select="$default"/>
        <xsl:value-of select="$suffix"/>
      </xsl:when>

      <xsl:otherwise>
        <xsl:value-of select="$this"/>
        <xsl:value-of select="$suffix"/>
      </xsl:otherwise>
    </xsl:choose>
    
  </td>
    <xsl:call-template name ="sign">
      <xsl:with-param name="this" select="$this" />
    </xsl:call-template>
  <td class="t_line04">
    <xsl:choose>
      <xsl:when test="$except and $this/@master = $except">
        <xsl:value-of select="$exdesc"/>
      </xsl:when>
      <xsl:when test="not($this/@master)">
        
      </xsl:when>
      <xsl:when test="$this/@master = ''">
        <xsl:value-of select="$default"/>
        <xsl:value-of select="$suffix"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$this/@master"/>
        <xsl:value-of select="$suffix"/>
      </xsl:otherwise>
    </xsl:choose>
    
  </td>
  </xsl:template>
  
  <!--<xsl:template name="KeyBoard">
    <xsl:param name="this"/>
    <tr>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05"></td>
      <td class="t_line05">
        キーボード <xsl:value-of select="position()"/>
      </td>
      <td class="t_line05">言語</td>
      <td class="t_line05"></td>
      <td class="t_line04">
      <xsl:if test="contains($this/text(), '@')">
        <xsl:call-template name="language" >
          <xsl:with-param name="countrycode" select="substring-before($this/text(),'@')"/>
        </xsl:call-template>  
      </xsl:if>
      <xsl:if test="not(contains($this/text(), '@'))">  
        <xsl:call-template name="language" >
            <xsl:with-param name="countrycode" select="$this/text()"/>
        </xsl:call-template>
      </xsl:if>
      </td>
      <td class="t_line06">
        <xsl:attribute name="rowspan">
          <xsl:choose>
            <xsl:when test="$this/text() = 'emoji'">1</xsl:when>
            <xsl:when test="$this/@master = 'emoji'">1</xsl:when>
            <xsl:when test="starts-with($this/text(),'emoji@')">1</xsl:when>
            <xsl:when test="starts-with($this/@master,'emoji@')">1</xsl:when>
            <xsl:when test="starts-with($this/text(),'ja_JP-Kana')">4</xsl:when>
            <xsl:when test="starts-with($this/@master,'ja_JP-Kana')">4</xsl:when>
            <xsl:when test="starts-with($this/text(),'ja_JP-Romaji')">3</xsl:when>
            <xsl:when test="starts-with($this/@master,'ja_JP-Romaji')">3</xsl:when>
            <xsl:otherwise>3</xsl:otherwise>
          </xsl:choose>
        </xsl:attribute>
        <xsl:choose>
          <xsl:when test="not($this/@match)">
            <img src="images/ball_gray.gif" width="15" height="15" />
            <xsl:value-of select="$this/@match"/>
          </xsl:when>
          <xsl:when test="$this/@match = 'true'">
            <img src="images/ball_green.gif" width="15" height="15" />
          </xsl:when>
          <xsl:when test="$this/@match = 'false'">
            <img src="images/ball_red.gif" width="15" height="15" />
          </xsl:when>
          <xsl:when test="$this/@match = 'extra'">
            <img src="images/ball_red.gif" width="15" height="15" />
          </xsl:when>
          <xsl:when test="$this/@match = 'short'">
            <img src="images/ball_red.gif" width="15" height="15" />
          </xsl:when>
        </xsl:choose>
      </td>
      <td class="t_line04">
        <xsl:if test="contains($this/@master, '@')">
          <xsl:call-template name="language" >
            <xsl:with-param name="countrycode" select="substring-before($this/@master,'@')"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="not(contains($this/@master, '@'))">
          <xsl:call-template name="language" >
            <xsl:with-param name="countrycode" select="$this/@master"/>
          </xsl:call-template>
        </xsl:if>
      </td>
    </tr>
    <xsl:if test="not(starts-with($this/text(),'emoji')) and not(starts-with($this/@master,'emoji'))">
      <tr>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05"></td>
        <td class="t_line05">ソフトウェアキーボード配列</td>
        <td class="t_line05"></td>
        <td class="t_line04">
          <xsl:call-template name="keyboard_sw" >
            <xsl:with-param name="key" select="$this"/>
          </xsl:call-template>
        </td>
        <td class="t_line04">
          <xsl:call-template name="keyboard_sw" >
            <xsl:with-param name="key" select="$this/@master"/>
          </xsl:call-template>
        </td>
      </tr>
        <tr>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05">ハードウェアキーボード配列</td>
          <td class="t_line05"></td>
          <td class="t_line04">
            <xsl:call-template name="keyboard_hw" >
              <xsl:with-param name="key" select="$this"/>
            </xsl:call-template>
          </td>
          <td class="t_line04">
            <xsl:call-template name="keyboard_hw" >
              <xsl:with-param name="key" select="$this/@master"/>
            </xsl:call-template>
          </td>
        </tr>
      <xsl:if test="starts-with($this/text(),'ja_JP-Kana') or starts-with($this/@master,'ja_JP-Kana')">
        <tr>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05"></td>
          <td class="t_line05">かなオプション</td>
          <td class="t_line05">フリックのみ</td>
          <td class="t_line04">
            <xsl:call-template name="keyboard_kana" >
              <xsl:with-param name="key" select="$this"/>
            </xsl:call-template>
          </td>
          <td class="t_line04">
            <xsl:call-template name="keyboard_kana" >
              <xsl:with-param name="key" select="$this/@master"/>
            </xsl:call-template>
          </td>
        </tr>
      </xsl:if>
    </xsl:if>
  </xsl:template>-->

  <xsl:template name="Margin">
    <xsl:param name="margin"/>
    <br/>誤差許容範囲:<xsl:value-of select="number($margin) * 100"/>%
  </xsl:template>

  <xsl:template name="settingtable">
    <xsl:param name="id"/>
    <xsl:param name="title1"/>
    <xsl:param name="title2"/>
    <xsl:param name="title3"/>
    <xsl:param name="title4"/>
    <xsl:param name="title5"/>
    <xsl:param name="title6"/>
    <xsl:param name="template"/>
    <xsl:param name="param1"/>
    <xsl:param name="param2"/>
    <xsl:param name="param3"/>
    <xsl:param name="param4"/>
    <xsl:param name="valueNode"/>
    <xsl:param name="value"/>
    <xsl:param name="sign"/>
    <xsl:param name="rowspan"/>
    <xsl:param name="nosign"/>
    <xsl:param name="mastervalue"/>
    <xsl:param name="create"/>
    
    <tr>
      <xsl:attribute name="id">
        <xsl:value-of select="$id"/>
      </xsl:attribute>
      <td class="t_line05 wordbreak">
        <xsl:value-of select="$title1"/>
      </td>
      <td class="t_line05 wordbreak">
        <xsl:value-of select="$title2"/>
      </td>
      <td class="t_line05 wordbreak">
        <xsl:value-of select="$title3"/>
      </td>
      <td class="t_line05 wordbreak">
        <xsl:value-of select="$title4"/>
      </td>
      <td class="t_line05 wordbreak">
        <xsl:value-of select="$title5"/>
      </td>
      <td class="t_line05 wordbreak">
        <xsl:value-of select="$title6"/>
      </td>
      <xsl:if test="not($template)">
        <td class="t_line04 wordbreak">
          <xsl:copy-of select="$value"/>
        </td>
        <xsl:choose>
          <xsl:when test="$nosign">
          </xsl:when>
          <xsl:when test="not($sign)">
            <xsl:call-template name="sign">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$sign">
            <td class="t_line06">
              <xsl:if test="$rowspan">
                <xsl:attribute name="rowspan">
                  <xsl:value-of select="$rowspan"/>
                </xsl:attribute>
              </xsl:if>
              <xsl:copy-of select="$sign"/>
            </td>
          </xsl:when>
        </xsl:choose>
        <td class="t_line04 wordbreak">
          <xsl:if test="$mastervalue">
            <xsl:copy-of select="$mastervalue"/>
          </xsl:if>
          <xsl:if test="not($mastervalue)">
            <xsl:value-of select="$value/@master"/>
          </xsl:if>
        </td>
      </xsl:if>
      <xsl:if test="$template">
        <xsl:choose>
          <xsl:when test="$template = 'text'">
            <xsl:call-template name="text">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'defaultOff'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="defaultOff">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="defaultOff">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'defaultOn'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="defaultOn">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="defaultOn">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'OnOff'">
            <xsl:if test="not($param1 and $param2)">
              <xsl:call-template name="OnOff">
                <xsl:with-param name="bool" select="$valueNode"/>
              </xsl:call-template>
            </xsl:if>
            <xsl:if test="$param1 and $param2">
              <xsl:call-template name="OnOff">
                <xsl:with-param name="bool" select="$valueNode"/>
                <xsl:with-param name="label-on" select="$param1"/>
                <xsl:with-param name="label-off" select="$param2"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:when>
          <xsl:when test="$template = 'maxInactivity'">
            <xsl:call-template name="maxInactivity">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'countryname'">
            <xsl:call-template name="countryname">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'allowExplicitContent'">
            <xsl:call-template name="allowExplicitContent">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'SBParentalControlsCapabilities'">
          <xsl:call-template name="SBParentalControlsCapabilities">
            <xsl:with-param name="capability" select="$valueNode"/>
          </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'maxGracePeriod'">
            <xsl:call-template name="maxGracePeriod">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'zeroIsOn'">
            <xsl:call-template name="zeroIsOn">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization'">
            <xsl:call-template name="Authorization">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization2'">
            <xsl:call-template name="Authorization2">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'Authorization3'">
            <xsl:call-template name="Authorization3">
              <xsl:with-param name="this" select="$valueNode"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$template = 'specifiedefSuffix'">
            <xsl:call-template name="specifiedefSuffix">
              <xsl:with-param name="this" select="$valueNode"/>
              <xsl:with-param name="default" select="$param1"/>
              <xsl:with-param name="suffix" select="$param2"/>
              <xsl:with-param name="except" select="$param3"/>
              <xsl:with-param name="exdesc" select="$param4"/>
            </xsl:call-template>
          </xsl:when>
        </xsl:choose>
      
      </xsl:if>
    </tr>
  </xsl:template>
  
</xsl:stylesheet>