<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

  <xsl:template name="SectionRestrict">

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'SBParentalControlsEnabled'" />
      <xsl:with-param name="title2" select="'機能制限'" />
      <xsl:with-param name="valueNode" select="/RESULT/SBParentalControlsEnabled" />
      <xsl:with-param name="template" select="'defaultOff'"/>
    </xsl:call-template>

    <!--許可-->
    <xsl:if test="/RESULT/SBParentalControlsEnabled = 'true'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowSafari'" />
        <xsl:with-param name="title3" select="'許可'" />
        <xsl:with-param name="title4" select="'Safari'" />
        <xsl:with-param name="valueNode" select="/RESULT/allowSafari" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowCamera'" />
        <xsl:with-param name="title4" select="'カメラ'" />
        <xsl:with-param name="valueNode" select="/RESULT/allowCamera" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:variable name="restrictFaceTime">
      <xsl:if test="/RESULT/allowVideoConferencing and /RESULT/ModelNumber != 'MC131' and /RESULT/ModelNumber != 'MC133'">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowVideoConferencing'" />
          <xsl:with-param name="title4" select="'FaceTime'" />
          <xsl:with-param name="valueNode" select="/RESULT/allowVideoConferencing" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:if>
      </xsl:variable>

      <xsl:variable name="restrictSiri">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowAssistant'" />
          <xsl:with-param name="title4" select="'Siriと音声入力'" />
          <xsl:with-param name="valueNode" select="/RESULT/allowAssistant" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="restrictAirDrop">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowAirDrop'" />
          <xsl:with-param name="title4" select="'AirDrop'" />
          <xsl:with-param name="valueNode" select="/RESULT/allowAirDrop" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="restrictCarPlay">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowVehicleUI'" />
          <xsl:with-param name="title4" select="'CarPlay'" />
          <xsl:with-param name="valueNode" select="/RESULT/allowVehicleUI" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="restrictInApp">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowInAppPurchases'" />
          <xsl:with-param name="title4">
            <xsl:choose>
              <xsl:when test="$MajorVersion &gt;= 8">
                <xsl:text>App内課金</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>App内での購入</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/RESULT/allowInAppPurchases" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:if test="$MajorVersion &lt; 7">
        <xsl:copy-of select="$restrictFaceTime"/>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:copy-of select="$restrictSiri"/>
        <xsl:copy-of select="$restrictFaceTime"/>
        <xsl:copy-of select="$restrictAirDrop"/>
        <xsl:if test="starts-with(/RESULT/DeviceClass, 'iPhone')">
          <xsl:copy-of select="$restrictCarPlay"/>
        </xsl:if>
      </xsl:if>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowiTunes'" />
        <xsl:with-param name="title4" select="'iTunes Store'" />
        <xsl:with-param name="valueNode" select="/RESULT/allowiTunes" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:if test="$MajorVersion &gt;= 9">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowMusicArtistActivity'" />
          <xsl:with-param name="title4">
            <xsl:choose>
              <xsl:when test="$MajorVersion &gt;= 11">
                <xsl:text>ミュージックのプロフィールと投稿</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>Apple Music Connect</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/RESULT/allowMusicArtistActivity" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:if>
      
      <xsl:if test="/RESULT/allowBookstore">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowBookstore'" />
          <xsl:with-param name="title4" select="'iBooks Store'" />
          <xsl:with-param name="valueNode" select="/RESULT/allowBookstore" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowPodcasts'" />
        <xsl:with-param name="title4" select="'Podcast'" />
        <xsl:with-param name="valueNode" select="/RESULT/allowPodcasts" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowAppInstallation'" />
        <xsl:with-param name="title4" select="'インストール'" />
        <xsl:with-param name="valueNode" select="/RESULT/allowAppInstallation" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowAppRemoval'" />
        <xsl:with-param name="title4" select="'Appの削除'" />
        <xsl:with-param name="valueNode" select="/RESULT/allowAppRemoval" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:if test="$MajorVersion &gt;= 7">
        <xsl:copy-of select="$restrictInApp"/>
      </xsl:if>


      <xsl:if test="/RESULT/ModelNumber != 'MC131' and /RESULT/ModelNumber != 'MC133'">
        <xsl:if test="$MajorVersion = 6">
          <xsl:copy-of select="$restrictSiri"/>
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'forceAssistantProfanityFilter'" />
            <xsl:with-param name="title4" select="'不適切な言葉'" />
            <xsl:with-param name="valueNode" select="/RESULT/forceAssistantProfanityFilter" />
            <xsl:with-param name="value">
              <xsl:call-template name="falseOn">
                <xsl:with-param name="bool" select="/RESULT/forceAssistantProfanityFilter"/>
              </xsl:call-template>
            </xsl:with-param>
            <xsl:with-param name="mastervalue">
              <xsl:call-template name="falseOn">
                <xsl:with-param name="bool" select="/RESULT/forceAssistantProfanityFilter/@master"/>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
      </xsl:if>

      <xsl:if test="$MajorVersion = 7">
        <xsl:if test="starts-with(/RESULT/ProductVersion, '7.1')">
          <xsl:copy-of select="$restrictSiri"/>
        </xsl:if>
        <xsl:copy-of select="$restrictAirDrop"/>
        <xsl:if test="starts-with(/RESULT/ProductVersion, '7.1')">
          <xsl:copy-of select="$restrictCarPlay"/>
        </xsl:if>
      </xsl:if>

      <!--コンテンツの許可-->
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'countryCode'" />
        <xsl:with-param name="title3" select="'コンテンツの許可'" />
        <xsl:with-param name="title4">
          <xsl:choose>
            <xsl:when test="$MajorVersion &gt;= 10">
              <xsl:text>制限の地域指定</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>レートの対象</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/RESULT/countryCode" />
        <xsl:with-param name="template" select="'countryname'"/>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowExplicitContent'" />
        <xsl:with-param name="title4">
          <xsl:choose>
            <xsl:when test="$MajorVersion &gt;= 10">
              <xsl:text>音楽、Podcast、ニュース</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>音楽とPodcast</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/RESULT/allowExplicitContent" />
        <xsl:with-param name="template" select="'allowExplicitContent'"/>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ratingMovies'" />
        <xsl:with-param name="title4">
          <xsl:choose>
            <xsl:when test="$MajorVersion &gt;= 10">
              <xsl:text>映画</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>ムービー</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/RESULT/ratingMovies" />
        <xsl:with-param name="value">
          <xsl:call-template name="ratingMovies">
            <xsl:with-param name="value" select="/RESULT/ratingMovies"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:call-template name="ratingMovies">
            <xsl:with-param name="value" select="/RESULT/ratingMovies/@master"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ratingTVShows'" />
        <xsl:with-param name="title4" select="'テレビ番組'" />
        <xsl:with-param name="valueNode" select="/RESULT/ratingTVShows" />
        <xsl:with-param name="value">
          <xsl:call-template name="ratingTVShows">
            <xsl:with-param name="value" select="/RESULT/ratingTVShows"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:call-template name="ratingTVShows">
            <xsl:with-param name="value" select="/RESULT/ratingTVShows/@master"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowBookstoreErotica'" />
        <xsl:with-param name="title4" select="'ブック'" />
        <xsl:with-param name="title5" select="'不適切な性的描写'" />
        <xsl:with-param name="valueNode" select="/RESULT/allowBookstoreErotica" />
        <xsl:with-param name="template" select="'defaultOff'"/>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ratingApps'" />
        <xsl:with-param name="title4" select="'App'" />
        <xsl:with-param name="valueNode" select="/RESULT/ratingApps" />
        <xsl:with-param name="value">
          <xsl:call-template name="ratingApps">
            <xsl:with-param name="value" select="/RESULT/ratingApps"/>
          </xsl:call-template>
        </xsl:with-param>
        <xsl:with-param name="mastervalue">
          <xsl:call-template name="ratingApps">
            <xsl:with-param name="value" select="/RESULT/ratingApps/@master"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:if test="$MajorVersion &gt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'forceAssistantProfanityFilter'" />
          <xsl:with-param name="title4" select="'Siri'" />
          <xsl:with-param name="title5" select="'不適切な言葉'" />
          <xsl:with-param name="valueNode" select="/RESULT/forceAssistantProfanityFilter" />
          <xsl:with-param name="value">
            <xsl:call-template name="falseOn">
              <xsl:with-param name="bool" select="/RESULT/forceAssistantProfanityFilter"/>
            </xsl:call-template>
          </xsl:with-param>
          <xsl:with-param name="mastervalue">
            <xsl:call-template name="falseOn">
              <xsl:with-param name="bool" select="/RESULT/forceAssistantProfanityFilter/@master"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowAssistantUserGeneratedContent'" />
          <xsl:with-param name="title5" select="'Web検索コンテンツ'" />
          <xsl:with-param name="valueNode" select="/RESULT/allowAssistantUserGeneratedContent" />
          <xsl:with-param name="template" select="'defaultOff'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt; 7">
        <xsl:copy-of select="$restrictInApp"/>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'restrictWeb'" />
          <xsl:with-param name="title4" select="'Webサイト'" />
          <xsl:with-param name="valueNode" select="/RESULT/restrictWeb" />
          <xsl:with-param name="value">
            <xsl:call-template name="restrictWeb2">
              <xsl:with-param name="whitelistEnabled" select="/RESULT/restrictWeb/whitelistEnabled"/>
              <xsl:with-param name="useContentFilter" select="/RESULT/restrictWeb/useContentFilter"/>
            </xsl:call-template>
          </xsl:with-param>
          <!--<xsl:with-param name="sign" select="' '"/>-->
          <xsl:with-param name="mastervalue">
            <xsl:call-template name="restrictWeb2">
              <xsl:with-param name="whitelistEnabled" select="/RESULT/restrictWeb/whitelistEnabled/@master"/>
              <xsl:with-param name="useContentFilter" select="/RESULT/restrictWeb/useContentFilter/@master"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt; 9">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'forceITunesStorePasswordEntry'" />
          <xsl:with-param name="title4" select="'パスワードを要求'" />
          <xsl:with-param name="valueNode" select="/RESULT/forceITunesStorePasswordEntry" />
          <xsl:with-param name="value">
            <xsl:call-template name="forceITunesStorePasswordEntry">
              <xsl:with-param name="value" select="forceITunesStorePasswordEntry/text()"/>
            </xsl:call-template>
          </xsl:with-param>
          <xsl:with-param name="mastervalue">
            <xsl:call-template name="forceITunesStorePasswordEntry">
              <xsl:with-param name="value" select="forceITunesStorePasswordEntry/@master"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 9">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AccountPaidPurchasesPasswordSetting'" />
          <xsl:with-param name="title4" select="'パスワードの設定'" />
          <xsl:with-param name="title5" select="'購入とApp内課金'" />
          <xsl:with-param name="valueNode" select="/RESULT/AccountPaidPurchasesPasswordSetting" />
          <xsl:with-param name="value">
            <xsl:call-template name="AccountPaidPurchasesPasswordSetting">
              <xsl:with-param name="value" select="AccountPaidPurchasesPasswordSetting/text()"/>
            </xsl:call-template>
          </xsl:with-param>
          <xsl:with-param name="mastervalue">
            <xsl:call-template name="AccountPaidPurchasesPasswordSetting">
              <xsl:with-param name="value" select="AccountPaidPurchasesPasswordSetting/@master"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AccountFreeDownloadsPasswordEnabled'" />
          <xsl:with-param name="title5" select="'無料ダウンロード'" />
          <xsl:with-param name="title6" select="'パスワードを要求'" />
          <xsl:with-param name="valueNode" select="/RESULT/AccountFreeDownloadsPasswordEnabled" />
          <xsl:with-param name="template" select="'defaultOn'" />
        </xsl:call-template>
        
      </xsl:if>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'SBParentalControlsCapabilities/location'" />
        <xsl:with-param name="title3" select="'プライバシー'" />
        <xsl:with-param name="title4" select="'位置情報サービス'" />
        <xsl:with-param name="title5" select="'変更を許可'" />
        <xsl:with-param name="valueNode" select="/RESULT/SBParentalControlsCapabilities/location" />
        <xsl:with-param name="template" select="'SBParentalControlsCapabilities'"/>
      </xsl:call-template>

    </xsl:if>




  </xsl:template>

</xsl:stylesheet>