<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
exclude-result-prefixes="msxsl">

  <xsl:template name="Section002">
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'DeviceName'" />
      <xsl:with-param name="title1" select="'一般'" />
	  <xsl:with-param name="title2" select="'情報'" />
	  <xsl:with-param name="title3" select="'名前'" />
      <xsl:with-param name="valueNode" select="/Root/DeviceName" />
      <xsl:with-param name="template" select="'text'"/>
    </xsl:call-template>

    <xsl:variable name="SystemVersion">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ProductVersion'" />
        <xsl:with-param name="title3">
          <xsl:choose>
            <xsl:when test="$MajorVersion = 12">ソフトウェア</xsl:when>
            <xsl:when test="$MajorVersion &gt;= 13">システム</xsl:when>
          </xsl:choose>
          <xsl:text>バージョン</xsl:text>
        </xsl:with-param>
        <xsl:with-param name="title4" select="'プロダクトバージョン'" />
        <xsl:with-param name="valueNode" select="/Root/ProductVersion" />
        <xsl:with-param name="template" select="'text'" />
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'BuildVersion'" />
        <xsl:with-param name="title4" select="'ビルドバージョン'" />
        <xsl:with-param name="valueNode" select="/Root/BuildVersion" />
        <xsl:with-param name="template" select="'text'" />
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="ModelSerial">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ModelNumber'" />
        <xsl:with-param name="title3" select="'モデル'" />
        <xsl:with-param name="valueNode" select="/Root/ModelNumber" />
        <xsl:with-param name="template" select="'text'" />
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'SerialNumber'" />
        <xsl:with-param name="title3" select="'シリアル番号'" />
        <xsl:with-param name="valueNode" select="/Root/SerialNumber" />
        <xsl:with-param name="template" select="'text'" />
      </xsl:call-template>
    </xsl:variable>

    <xsl:if test="$MajorVersion &gt;= 12">
      <xsl:copy-of select="$SystemVersion"/>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'MarketingName'" />
        <xsl:with-param name="title3" select="'機種名'" />
        <xsl:with-param name="valueNode" select="/Root/MarketingName" />
        <xsl:with-param name="template" select="'text'" />
      </xsl:call-template>

      <xsl:copy-of select="$ModelSerial"/>
    </xsl:if>
    
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'Network'" />
      <xsl:with-param name="title3" select="'ネットワーク'" />
      <xsl:with-param name="value">
	    <xsl:call-template name="Network">
              <xsl:with-param name ="country" select="/Root/MobileSubscriberCountryCode"/>
              <xsl:with-param name ="network" select="/Root/MobileSubscriberNetworkCode"/>
            </xsl:call-template>
	  </xsl:with-param>
    </xsl:call-template>
	
    <xsl:if test="/Root/AirplaneModeEnabled = 'false' and /Root/SIMState = 'kCTSIMSupportSIMStatusReady'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'MobileSubscriber'" />
        <xsl:with-param name="title3" select="'回線'" />
        <xsl:with-param name="value">
	      <xsl:call-template name="Network">
                <xsl:with-param name ="country" select="/Root/MobileSubscriberCountryCode"/>
                <xsl:with-param name ="network" select="/Root/MobileSubscriberNetworkCode"/>
              </xsl:call-template>
	    </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
    
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'MusicCount'" />
      <xsl:with-param name="title3" select="'曲'" />
      <xsl:with-param name="valueNode" select="/Root/MusicCount" />
      <xsl:with-param name="template" select="'text'"/>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'VideoCount'" />
      <xsl:with-param name="title3" select="'ビデオ'" />
      <xsl:with-param name="valueNode" select="/Root/VideoCount" />
      <xsl:with-param name="template" select="'text'"/>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'PhotoCount'" />
      <xsl:with-param name="title3" select="'写真'" />
      <xsl:with-param name="valueNode" select="/Root/PhotoCount" />
      <xsl:with-param name="template" select="'text'"/>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'AppCount'" />
      <xsl:with-param name="title3" select="'App'" />
      <xsl:with-param name="valueNode" select="/Root/AppCount" />
      <xsl:with-param name="template" select="'text'"/>
    </xsl:call-template>
    
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'DataCapacity'" />
          <xsl:with-param name="title3" select="'容量'" />
          <xsl:with-param name="value">
            <xsl:value-of select="round(/Root/DiskCapacity div 1000)"/>GB
          </xsl:with-param>
        </xsl:call-template>

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AmountDataAvailable'" />
          <xsl:with-param name="title3" select="'使用可能'" />
          <xsl:with-param name="value">
            <xsl:value-of select="round(/Root/DataAvailable div 10) div 100"/>GB
          </xsl:with-param>
        </xsl:call-template>


    <xsl:if test="$MajorVersion &lt;= 11">
      <xsl:copy-of select="$SystemVersion"/>
    </xsl:if>


    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'CarrierBundleName'" />
      <xsl:with-param name="title3" select="'キャリア'" />
      <xsl:with-param name="valueNode" select="/Root/CarrierBundleName" />
      <xsl:with-param name="value">
        <xsl:call-template name="NetworkCarrier">
          <xsl:with-param name ="carrier" select="/Root/CarrierBundleName"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'CarrierBundleVersion'" />
      <xsl:with-param name="title4" select="'バージョン'" />
      <xsl:with-param name="valueNode" select="/Root/CarrierBundleVersion" />
      <xsl:with-param name="template" select="'text'"/>
    </xsl:call-template>


    <xsl:if test="$MajorVersion &lt;= 11">
      <xsl:copy-of select="$ModelSerial"/>
    </xsl:if>
	
	<xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'PhoneNumber'" />
	  <xsl:with-param name="title3" select="'データ通信契約番号'" />
      <xsl:with-param name="value" select="/Root/PhoneNumber" />
    </xsl:call-template>
	
	<xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'WiFiAddress'" />
	  <xsl:with-param name="title3" select="'Wi-Fiアドレス'" />
      <xsl:with-param name="value" select="/Root/WiFiAddress" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'BluetoothAddress'" />
      <xsl:with-param name="title3" select="'Bluetooth'" />
      <xsl:with-param name="value" select="/Root/BluetoothAddress" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'IMEI'" />
      <xsl:with-param name="title3" select="'IMEI'" />
      <xsl:with-param name="value">
        <xsl:value-of select="substring(/Root/IMEI, 1, 2)"/>&#160;
        <xsl:value-of select="substring(/Root/IMEI, 3, 6)"/>&#160;
        <xsl:value-of select="substring(/Root/IMEI, 9, 6)"/>&#160;
        <xsl:value-of select="substring(/Root/IMEI, 15, 1)"/>&#160;
      </xsl:with-param>
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'ICCID'" />
      <xsl:with-param name="title3" select="'ICCID'" />
      <xsl:with-param name="value">
        <xsl:value-of select="substring(/Root/ICCID, 1, 4)"/>&#160;
        <xsl:value-of select="substring(/Root/ICCID, 5, 4)"/>&#160;
        <xsl:value-of select="substring(/Root/ICCID, 9, 4)"/>&#160;
        <xsl:value-of select="substring(/Root/ICCID, 13, 4)"/>&#160;
        <xsl:value-of select="substring(/Root/ICCID, 17, 3)"/>
      </xsl:with-param>
    </xsl:call-template>

    <xsl:if test="starts-with(/Root/ProductVersion, '7.1') or $MajorVersion &gt;= 8">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'MEID'" />
        <xsl:with-param name="title3" select="'MEID'" />
        <xsl:with-param name="value" select="/Root/MEID" />
      </xsl:call-template>
    </xsl:if>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'BasebandVersion'" />
      <xsl:with-param name="title3" select="'モデムファームウェア'" />
      <xsl:with-param name="valueNode" select="/Root/BasebandVersion" />
      <xsl:with-param name="template" select="'text'" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'SEID'" />
      <xsl:with-param name="title3" select="'SEID'" />
      <xsl:with-param name="value" select="/Root/SEID" />
    </xsl:call-template>

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'DeviceIdentifier'" />
      <xsl:with-param name="title3" select="'UDID'" />
      <xsl:with-param name="value" select="/Root/DeviceIdentifier" />
    </xsl:call-template>
    
  </xsl:template>

</xsl:stylesheet>