<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

  <xsl:template name="SectionLocationService">
    <xsl:param name="privacy" select="0" />

    <!--プライバシー-->
    <xsl:if test="$MajorVersion &gt;= 8">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'LocationServicesEnabledIn8.0'" />
        <xsl:with-param name="title1">
          <xsl:if test="$privacy = 1">
            <xsl:text>プライバシー</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title2">
          <xsl:if test="$privacy = 1">
            <xsl:text>位置情報サービス</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title5">
          <xsl:if test="$privacy = 0">
            <xsl:text>位置情報サービス</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/LocationServicesEnabledIn8.0" />
        <xsl:with-param name="template" select="'defaultOff'"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$MajorVersion = 7">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'LocationServicesEnabledIn7.0'" />
        <xsl:with-param name="title5" select="'位置情報サービス'" />
        <xsl:with-param name="valueNode" select="/Root/LocationServicesEnabledIn7.0" />
        <xsl:with-param name="template" select="'defaultOff'"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:if test="$MajorVersion &lt; 7">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'LocationServicesEnabled'" />
        <xsl:with-param name="title5" select="'位置情報サービス'" />
        <xsl:with-param name="valueNode" select="/Root/LocationServicesEnabled" />
        <xsl:with-param name="template" select="'defaultOff'"/>
      </xsl:call-template>
    </xsl:if>

    <xsl:if test="$MajorVersion &gt;= 13">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'AuthorizationPromptMapDisplayEnabled'" />
        <xsl:with-param name="title5" select="'位置情報の通知'" />
        <xsl:with-param name="title6" select="'位置情報の通知で“マップ”を表示'" />
        <xsl:with-param name="valueNode" select="/Root/AuthorizationPromptMapDisplayEnabled" />
        <xsl:with-param name="template" select="'defaultOn'"/>
      </xsl:call-template>
    </xsl:if>

    <!--<xsl:if test="$MajorVersion &gt;= 8">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'kFMFTapMessages'" />
        <xsl:with-param name="title2">
          <xsl:if test="$privacy = 1">
            <xsl:text>自分の位置情報を共有</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title3">
          <xsl:if test="$privacy = 1">
            <xsl:text>位置情報を共有</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title5">
          <xsl:if test="$privacy = 0">
            <xsl:text>自分の位置情報を共有</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title6">
          <xsl:if test="$privacy = 0">
            <xsl:text>位置情報を共有</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/kFMFTapMessages" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/Root/kFMFTapMessages != ''">
              <xsl:text>オン</xsl:text>
            </xsl:when>
            <xsl:when test="/Root/kFMFTapMessages = ''">
              <xsl:text>オフ</xsl:text>
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>-->

    <xsl:if test="/Root/LocationServicesEnabled/text()='1' or /Root/LocationServicesEnabledIn7.0/text()='1' or /Root/LocationServicesEnabledIn7.0/text()='true' or /Root/LocationServicesEnabledIn8.0/text()='1' or /Root/LocationServicesEnabledIn8.0/text()='true'">
      <xsl:for-each select="/Root/LocationServices/Service">
        <xsl:sort select="cs:GetAppName(Identifier, /Root/DeviceClass, /Root/Applications)"/>
        <!--並び替え前の位置を取得-->
        <xsl:variable name="id" select="Identifier"/>
        <xsl:variable name="pos" select="count(/Root/LocationServices/Service[./Identifier = $id]/preceding-sibling::*)+1"/>

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="concat('LocationServices/Service_', $pos,'/Authorized')" />
          <xsl:with-param name="title2">
            <xsl:if test="$privacy = 1">
              <xsl:call-template name="GetAppName">
                <xsl:with-param name="appID" select="Identifier"/>
                <xsl:with-param name="device" select="/Root/DeviceClass"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title5">
            <xsl:if test="$privacy = 0">
              <xsl:call-template name="GetAppName">
                <xsl:with-param name="appID" select="Identifier"/>
                <xsl:with-param name="device" select="/Root/DeviceClass"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="Authorized" />
          <xsl:with-param name="value">
            <xsl:call-template name="defaultOff">
              <xsl:with-param name ="bool" select="Authorized"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:for-each>

      <!-- ios8 -->
      <xsl:for-each select="/Root/LocationServices8/Service">
        <xsl:sort select="cs:GetAppName(Identifier, /Root/DeviceClass, /Root/Applications, 'locationservice')"/>
        <!--並び替え前の位置を取得-->
        <xsl:variable name="id" select="Identifier"/>
        <xsl:variable name="pos" select="count(/Root/LocationServices8/Service[./Identifier = $id]/preceding-sibling::*)+1"/>

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="concat('LocationServices8/Service_', $pos,'/Authorization')" />
          <xsl:with-param name="title2">
            <xsl:if test="$privacy = 1">
              <xsl:call-template name="GetAppName">
                <xsl:with-param name="appID" select="Identifier"/>
                <xsl:with-param name="device" select="/Root/DeviceClass"/>
                <xsl:with-param name="type" select="'locationservice'"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title5">
            <xsl:if test="$privacy = 0">
              <xsl:call-template name="GetAppName">
                <xsl:with-param name="appID" select="Identifier"/>
                <xsl:with-param name="device" select="/Root/DeviceClass"/>
                <xsl:with-param name="type" select="'locationservice'"/>
              </xsl:call-template>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="Authorization" />
          <xsl:with-param name="template" select="'Authorization2'"/>
        </xsl:call-template>
      </xsl:for-each>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationAssistantServices'" />
          <xsl:with-param name="title5" select="'Siri'" />
          <xsl:with-param name="valueNode" select="/Root/locationAssistantServices" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>
      <!--<xsl:if test="$MajorVersion &gt;= 8">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'locationAssistantServices8'" />
            <xsl:with-param name="title5" select="'Siriと音声入力'" />
            <xsl:with-param name="valueNode" select="/Root/locationAssistantServices8" />
            <xsl:with-param name="template" select="'Authorization2'"/>
          </xsl:call-template>
        </xsl:if>-->

      <xsl:if test="/Root/locationWeather != '' or /Root/locationWeather8 != '' or /Root/locationWeather10 != ''">
        <xsl:if test="$MajorVersion &lt;= 7">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'locationWeather'" />
            <xsl:with-param name="title5" select="'天気'" />
            <xsl:with-param name="valueNode" select="/Root/locationWeather" />
            <xsl:with-param name="template" select="'defaultOn'"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 8 and $MajorVersion &lt;= 9">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'locationWeather8'" />
            <xsl:with-param name="title5" select="'天気'" />
            <xsl:with-param name="valueNode" select="/Root/locationWeather8" />
            <xsl:with-param name="template" select="'Authorization2'"/>
          </xsl:call-template>
        </xsl:if>
        <!--<xsl:if test="$MajorVersion &gt;= 10">
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'locationWeather10'" />
              <xsl:with-param name="title5" select="'天気'" />
              <xsl:with-param name="valueNode" select="/Root/locationWeather10" />
              <xsl:with-param name="template" select="'Authorization3'"/>
            </xsl:call-template>
          </xsl:if>-->
      </xsl:if>

      <xsl:variable name="locationAOSNotification">
        <xsl:choose>
          <xsl:when test="$MajorVersion &gt;= 9">
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'locationFindMyDevice'" />
              <xsl:with-param name="title3">
                <xsl:if test="$privacy = 1">
                  <xsl:value-of select="/Root/DeviceClass"/>
                  <xsl:text>を探す</xsl:text>
                </xsl:if>
              </xsl:with-param>
              <xsl:with-param name="title6">
                <xsl:if test="$privacy = 0">
                  <xsl:value-of select="/Root/DeviceClass"/>
                  <xsl:text>を探す</xsl:text>
                </xsl:if>
              </xsl:with-param>
              <xsl:with-param name="valueNode" select="/Root/locationFindMyDevice" />
              <xsl:with-param name="template" select="'Authorization'"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$MajorVersion = 8">
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'locationFindMyDevice'" />
              <xsl:with-param name="title5">
                <xsl:text>システムサービス</xsl:text>
              </xsl:with-param>
              <xsl:with-param name="title6">
                <xsl:value-of select="/Root/DeviceClass"/>を探す
              </xsl:with-param>
              <xsl:with-param name="valueNode" select="/Root/locationFindMyDevice" />
              <xsl:with-param name="template" select="'Authorization'"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'locationAOSNotification'" />
              <xsl:with-param name="title5">
                <xsl:value-of select="/Root/DeviceClass"/>を探す
              </xsl:with-param>
              <xsl:with-param name="title6">
                <xsl:value-of select="/Root/DeviceClass"/>を探す
              </xsl:with-param>
              <xsl:with-param name="valueNode" select="/Root/locationAOSNotification" />
              <xsl:with-param name="template" select="'defaultOn'"/>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:if test="/Root/locationAOSNotification != ''">
          <xsl:copy-of select="$locationAOSNotification"/>
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'StatusBarIconStatesFindMyiPhone'" />
            <xsl:with-param name="title6" select="'ステータスバーアイコン'" />
            <xsl:with-param name="valueNode" select="/Root/StatusBarIconStatesFindMyiPhone" />
            <xsl:with-param name="template" select="'defaultOff'"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:if>

      <xsl:variable name="locationAppGenius">
        <xsl:if test="$MajorVersion &lt;= 7">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'locationAppGenius'" />
            <xsl:with-param name="title5">
              <xsl:if test="$MajorVersion = 6">
                <xsl:text>システムサービス</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title6">
              <xsl:choose>
                <xsl:when test="$MajorVersion = 6">
                  <xsl:text>Genius for App</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>この近くで人気</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/locationAppGenius" />
            <xsl:with-param name="template" select="'defaultOn'"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 8">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'locationAppGenius8'" />
            <xsl:with-param name="title3">
              <xsl:if test="$privacy = 1">
                <xsl:text>この近くで人気</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title6">
              <xsl:if test="$privacy = 0">
                <xsl:text>この近くで人気</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/locationAppGenius8" />
            <xsl:with-param name="template" select="'Authorization'"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:variable>

      <xsl:variable name="locationMobileWiFi">
        <xsl:if test="$MajorVersion = 7">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'locationMobileWiFi'" />
            <xsl:with-param name="title5">
              <xsl:text>システムサービス</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="title6">
              <xsl:text>Wi-Fiネットワーキング</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/locationMobileWiFi" />
            <xsl:with-param name="template" select="'defaultOn'"/>
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$MajorVersion &gt;= 8">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'locationMobileWiFi8'" />
            <xsl:with-param name="title3">
              <xsl:if test="$privacy = 1">
                <xsl:text>Wi-Fiネットワーク</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="title6">
              <xsl:if test="$privacy = 0">
                <xsl:text>Wi-Fiネットワーク</xsl:text>
              </xsl:if>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/locationMobileWiFi8" />
            <xsl:with-param name="template" select="'Authorization'"/>
          </xsl:call-template>
        </xsl:if>
      </xsl:variable>

      <xsl:if test="$MajorVersion &lt;= 6">
        <xsl:copy-of select="$locationAppGenius"/>
      </xsl:if>

      <xsl:if test="$MajorVersion = 7">
        <xsl:copy-of select="$locationMobileWiFi"/>
        <xsl:copy-of select="$locationAppGenius"/>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 13">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationApplePay'" />
          <xsl:with-param name="title2">
            <xsl:if test="$privacy = 1">
              <xsl:text>システムサービス</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>Apple Pay Merchant Identification</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title5">
            <xsl:if test="$privacy = 0">
              <xsl:text>システムサービス</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>Apple Pay Merchant Identification</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationApplePay" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>
      
      <xsl:if test="$MajorVersion &gt;= 9">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationHomeKitDaemon'" />
          <xsl:with-param name="title2">
            <xsl:if test="$MajorVersion &lt; 13">
              <xsl:if test="$privacy = 1">
                <xsl:text>システムサービス</xsl:text>
              </xsl:if>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>Homekit</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title5">
            <xsl:if test="$MajorVersion &lt; 13">
              <xsl:if test="$privacy = 0">
                <xsl:text>システムサービス</xsl:text>
              </xsl:if>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>Homekit</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationHomeKitDaemon" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:copy-of select="$locationAOSNotification"/>

        <xsl:if test="$MajorVersion &lt;= 9">
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'locationParsec'" />
            <xsl:with-param name="title6">
              <xsl:if test="$MajorVersion &gt;= 9">
                <xsl:text>Safariと</xsl:text>
              </xsl:if>
              <xsl:text>Spotlightの検索結果</xsl:text>
            </xsl:with-param>
            <xsl:with-param name="valueNode" select="/Root/locationParsec" />
            <xsl:with-param name="template" select="'Authorization'"/>
          </xsl:call-template>
        </xsl:if>

        <xsl:copy-of select="$locationMobileWiFi"/>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationCompassCalibration'" />
          <xsl:with-param name="title6" select="'コンパスの調整'" />
          <xsl:with-param name="valueNode" select="/Root/locationCompassCalibration" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationCompassCalibration8'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>コンパスの調整</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>コンパスの調整</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationCompassCalibration8" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 13">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationSystemCustomization'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>システムカスタマイズ</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>システムカスタマイズ</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationSystemCustomization" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>
      
      <xsl:if test="$MajorVersion &gt;= 8">
        <!--モーションの調整-->
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationMotionCalibration'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>モーションの調整と距離</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 9">
                  <xsl:text>モーションの調整と距離</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>モーションの調整</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationMotionCalibration" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationiAdCore'" />
          <xsl:with-param name="title6" select="'位置情報に基づくiAd'" />
          <xsl:with-param name="valueNode" select="/Root/locationiAdCore" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationiAdCore8'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 10">
                  <xsl:text>位置情報に基づくApple Ads</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>位置情報に基づくiAd</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 10">
                  <xsl:text>位置情報に基づくApple Ads</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>位置情報に基づくiAd</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationiAdCore8" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>


      <xsl:if test="$MajorVersion &gt;= 10">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationCoreParsec'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>位置情報に基づく検索候補</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>位置情報に基づく検索候補</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationCoreParsec" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 8">
        <!--位置情報に基づく通知-->
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationAppSuggestions'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>位置情報に基づく通知</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>位置情報に基づく通知</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationAppSuggestions" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
        <!--位置情報を共有-->
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationFMF'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>位置情報を共有</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>位置情報を共有</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationFMF" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 10">
        <!--SOS-->
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationSOS'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>緊急</xsl:text>
              <xsl:if test="$MajorVersion &gt;= 12">
                <xsl:text>電話および</xsl:text>
              </xsl:if>
              <xsl:text>SOS</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>緊急</xsl:text>
              <xsl:if test="$MajorVersion &gt;= 12">
                <xsl:text>電話および</xsl:text>
              </xsl:if>
              <xsl:text>SOS</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationSOS" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationCoreTelephony'" />
          <xsl:with-param name="title6" select="'携帯電話通信網検索'" />
          <xsl:with-param name="valueNode" select="/Root/locationCoreTelephony" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationCoreTelephony8'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>携帯電話通信網検索</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>携帯電話通信網検索</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationCoreTelephony8" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>


      <xsl:variable name="locationTraffic">
        <xsl:choose>
          <xsl:when test="$MajorVersion &gt;= 9">
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'locationTraffic8'" />
              <xsl:with-param name="title3">
                <xsl:if test="$privacy = 1">
                  <xsl:text>経路と交通情報</xsl:text>
                </xsl:if>
              </xsl:with-param>
              <xsl:with-param name="title6">
                <xsl:if test="$privacy = 0">
                  <xsl:text>経路と交通情報</xsl:text>
                </xsl:if>
              </xsl:with-param>
              <xsl:with-param name="valueNode" select="/Root/locationTraffic8" />
              <xsl:with-param name="template" select="'Authorization'"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test="$MajorVersion = 8">
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'locationTraffic8'" />
              <xsl:with-param name="title3">
                <xsl:if test="$privacy = 1">
                  <xsl:text>交通情報</xsl:text>
                </xsl:if>
              </xsl:with-param>
              <xsl:with-param name="title6">
                <xsl:if test="$privacy = 0">
                  <xsl:text>交通情報</xsl:text>
                </xsl:if>
              </xsl:with-param>
              <xsl:with-param name="valueNode" select="/Root/locationTraffic8" />
              <xsl:with-param name="template" select="'Authorization'"/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name="settingtable">
              <xsl:with-param name="id" select="'locationTraffic'" />
              <xsl:with-param name="title3">
                <xsl:if test="$privacy = 1">
                  <xsl:text>交通情報</xsl:text>
                </xsl:if>
              </xsl:with-param>
              <xsl:with-param name="title6">
                <xsl:if test="$privacy = 0">
                  <xsl:text>交通情報</xsl:text>
                </xsl:if>
              </xsl:with-param>
              <xsl:with-param name="valueNode" select="/Root/locationTraffic" />
              <xsl:with-param name="template" select="'defaultOn'"/>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:copy-of select="$locationTraffic"/>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationTimeZone'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>時間帯の設定</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>時間帯の設定</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationTimeZone" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationTimeZone8'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>時間帯の設定</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>時間帯の設定</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationTimeZone8" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:variable name="AddressCorrectionAuthStatus">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AddressCorrectionAuthStatus'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 10">
                  <xsl:text>”マップ”の改善</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>”マップ”を改善</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 10">
                  <xsl:text>”マップ”の改善</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>”マップ”を改善</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/AddressCorrectionAuthStatus" />
          <xsl:with-param name="value">
            <xsl:call-template name="addrCollect">
              <xsl:with-param name="value" select="/Root/AddressCorrectionAuthStatus"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:variable>

      <xsl:if test="$MajorVersion = 7">
        <!--利用頻度の高い位置情報-->
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationRoutine'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>利用頻度の高い位置情報</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>利用頻度の高い位置情報</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationRoutine" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 8">
        <!--利用頻度の高い位置情報-->
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationRoutine8'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 11">
                  <xsl:text>利用頻度の高い場所</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>利用頻度の高い位置情報</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 11">
                  <xsl:text>利用頻度の高い場所</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>利用頻度の高い位置情報</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationRoutine8" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion = 7">
        <xsl:if test="/Root/locationRoutine = 'true'">
          <xsl:copy-of select="$AddressCorrectionAuthStatus"/>
        </xsl:if>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 8 and $MajorVersion &lt;= 9">
        <xsl:copy-of select="$locationAppGenius"/>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 8 and $MajorVersion &lt;= 9">
        <xsl:copy-of select="$locationTraffic"/>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationWirelessDiagnostics'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:text>診断/使用状況</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:text>診断/使用状況</xsl:text>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationWirelessDiagnostics" />
          <xsl:with-param name="template" select="'defaultOn'"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'locationWirelessDiagnostics8'" />
          <xsl:with-param name="title3">
            <xsl:if test="$privacy = 1">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 10">
                  <xsl:text>iPhone/iPad解析</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>診断/使用状況</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="title6">
            <xsl:if test="$privacy = 0">
              <xsl:choose>
                <xsl:when test="$MajorVersion &gt;= 10">
                  <xsl:text>iPhone/iPad解析</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>診断/使用状況</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/locationWirelessDiagnostics8" />
          <xsl:with-param name="template" select="'Authorization'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 10">
        <xsl:copy-of select="$locationAppGenius"/>
        <xsl:copy-of select="$locationTraffic"/>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:if test="/Root/locationRoutine8 = '4'">
          <xsl:copy-of select="$AddressCorrectionAuthStatus"/>
        </xsl:if>
      </xsl:if>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'StatusBarIconStatesSystemService'" />
        <xsl:with-param name="title3">
          <xsl:if test="$privacy = 1">
            <xsl:text>ステータスバーアイコン</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="title6">
          <xsl:if test="$privacy = 0">
            <xsl:text>ステータスバーアイコン</xsl:text>
          </xsl:if>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/StatusBarIconStatesSystemService" />
        <xsl:with-param name="template" select="'defaultOff'"/>
      </xsl:call-template>

    </xsl:if>


  </xsl:template>

</xsl:stylesheet>