<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                xmlns:cs="urn:custom-csharp"
exclude-result-prefixes="msxsl cs">

  <xsl:template name="SectionRestrict">

    <xsl:call-template name="settingtable">
      <xsl:with-param name="id" select="'SBParentalControlsEnabled'" />
      <xsl:with-param name="title2" select="'機能制限'" />
      <xsl:with-param name="valueNode" select="/Root/SBParentalControlsEnabled" />
      <xsl:with-param name="value">
        <xsl:call-template name="defaultOff">
          <xsl:with-param name="bool" select="/Root/SBParentalControlsEnabled"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>

    <!--許可-->
    <xsl:if test="/Root/SBParentalControlsEnabled = 'true'">
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowSafari'" />
        <xsl:with-param name="title3" select="'許可'" />
        <xsl:with-param name="title4" select="'Safari'" />
        <xsl:with-param name="valueNode" select="/Root/allowSafari" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowCamera'" />
        <xsl:with-param name="title4" select="'カメラ'" />
        <xsl:with-param name="valueNode" select="/Root/allowCamera" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:variable name="restrictFaceTime">
      <xsl:if test="/Root/allowVideoConferencing and /Root/ModelNumber != 'MC131' and /Root/ModelNumber != 'MC133'">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowVideoConferencing'" />
          <xsl:with-param name="title4" select="'FaceTime'" />
          <xsl:with-param name="valueNode" select="/Root/allowVideoConferencing" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:if>
      </xsl:variable>

      <xsl:variable name="restrictSiri">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowAssistant'" />
          <xsl:with-param name="title4" select="'Siriと音声入力'" />
          <xsl:with-param name="valueNode" select="/Root/allowAssistant" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="restrictAirDrop">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowAirDrop'" />
          <xsl:with-param name="title4" select="'AirDrop'" />
          <xsl:with-param name="valueNode" select="/Root/allowAirDrop" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="restrictCarPlay">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowVehicleUI'" />
          <xsl:with-param name="title4" select="'CarPlay'" />
          <xsl:with-param name="valueNode" select="/Root/allowVehicleUI" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:variable name="restrictInApp">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowInAppPurchases'" />
          <xsl:with-param name="title4">
            <xsl:choose>
              <xsl:when test="$MajorVersion &gt;= 8">
                <xsl:text>App内課金</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>App内での購入</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/allowInAppPurchases" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:variable>

      <xsl:if test="$MajorVersion &lt; 7">
        <xsl:copy-of select="$restrictFaceTime"/>
      </xsl:if>
      
      <xsl:if test="$MajorVersion &gt;= 8">
        <xsl:copy-of select="$restrictSiri"/>
        <xsl:copy-of select="$restrictFaceTime"/>
        <xsl:copy-of select="$restrictAirDrop"/>
        <xsl:if test="starts-with(/Root/DeviceClass, 'iPhone')">
          <xsl:copy-of select="$restrictCarPlay"/>
        </xsl:if>
      </xsl:if>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowiTunes'" />
        <xsl:with-param name="title4" select="'iTunes Store'" />
        <xsl:with-param name="valueNode" select="/Root/allowiTunes" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:if test="$MajorVersion &gt;= 9">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowMusicArtistActivity'" />
          <xsl:with-param name="title4">
            <xsl:choose>
              <xsl:when test="$MajorVersion &gt;= 11">
                <xsl:text>ミュージックのプロフィールと投稿</xsl:text>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text>Apple Music Connect</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:with-param>
          <xsl:with-param name="valueNode" select="/Root/allowMusicArtistActivity" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:if>
      
      <xsl:if test="/Root/allowBookstore">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowBookstore'" />
          <xsl:with-param name="title4" select="'iBooks Store'" />
          <xsl:with-param name="valueNode" select="/Root/allowBookstore" />
          <xsl:with-param name="template" select="'OnOff'"/>
        </xsl:call-template>
      </xsl:if>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowPodcasts'" />
        <xsl:with-param name="title4" select="'Podcast'" />
        <xsl:with-param name="valueNode" select="/Root/allowPodcasts" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowAppInstallation'" />
        <xsl:with-param name="title4" select="'インストール'" />
        <xsl:with-param name="valueNode" select="/Root/allowAppInstallation" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowAppRemoval'" />
        <xsl:with-param name="title4" select="'Appの削除'" />
        <xsl:with-param name="valueNode" select="/Root/allowAppRemoval" />
        <xsl:with-param name="template" select="'OnOff'"/>
      </xsl:call-template>

      <xsl:if test="$MajorVersion &gt;= 7">
        <xsl:copy-of select="$restrictInApp"/>
      </xsl:if>


      <xsl:if test="/Root/ModelNumber != 'MC131' and /Root/ModelNumber != 'MC133'">
        <xsl:if test="$MajorVersion = 6">
          <xsl:copy-of select="$restrictSiri"/>
          <xsl:call-template name="settingtable">
            <xsl:with-param name="id" select="'forceAssistantProfanityFilter'" />
            <xsl:with-param name="title4" select="'不適切な言葉'" />
            <xsl:with-param name="valueNode" select="/Root/forceAssistantProfanityFilter" />
            <xsl:with-param name="value">
              <xsl:call-template name="falseOn">
                <xsl:with-param name="bool" select="/Root/forceAssistantProfanityFilter"/>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:if>
      </xsl:if>

      <xsl:if test="$MajorVersion = 7">
        <xsl:if test="starts-with(/Root/ProductVersion, '7.1')">
          <xsl:copy-of select="$restrictSiri"/>
        </xsl:if>
        <xsl:copy-of select="$restrictAirDrop"/>
        <xsl:if test="starts-with(/Root/ProductVersion, '7.1')">
          <xsl:copy-of select="$restrictCarPlay"/>
        </xsl:if>
      </xsl:if>

      <!--コンテンツの許可-->
      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'countryCode'" />
        <xsl:with-param name="title3" select="'コンテンツの許可'" />
        <xsl:with-param name="title4">
          <xsl:choose>
            <xsl:when test="$MajorVersion &gt;= 10">
              <xsl:text>制限の地域指定</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>レートの対象</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/countryCode" />
        <xsl:with-param name="value">
          <xsl:call-template name="country">
            <xsl:with-param name="countrycode" select="/Root/countryCode" />
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowExplicitContent'" />
        <xsl:with-param name="title4">
          <xsl:choose>
            <xsl:when test="$MajorVersion &gt;= 10">
              <xsl:text>音楽、Podcast、ニュース</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>音楽とPodcast</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/allowExplicitContent" />
        <xsl:with-param name="value">
          <xsl:choose>
            <xsl:when test="/Root/allowExplicitContent/text()='true'">
              <xsl:text>不適切な内容</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>不適切な内容を含まない</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ratingMovies'" />
        <xsl:with-param name="title4">
          <xsl:choose>
            <xsl:when test="$MajorVersion &gt;= 10">
              <xsl:text>映画</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>ムービー</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
        <xsl:with-param name="valueNode" select="/Root/ratingMovies" />
        <xsl:with-param name="value">
          <xsl:call-template name="ratingMovies">
            <xsl:with-param name="value" select="/Root/ratingMovies"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ratingTVShows'" />
        <xsl:with-param name="title4" select="'テレビ番組'" />
        <xsl:with-param name="valueNode" select="/Root/ratingTVShows" />
        <xsl:with-param name="value">
          <xsl:call-template name="ratingTVShows">
            <xsl:with-param name="value" select="/Root/ratingTVShows"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'allowBookstoreErotica'" />
        <xsl:with-param name="title4" select="'ブック'" />
        <xsl:with-param name="title5" select="'不適切な性的描写'" />
        <xsl:with-param name="valueNode" select="/Root/allowBookstoreErotica" />
        <xsl:with-param name="value">
          <xsl:call-template name="defaultOff">
            <xsl:with-param name="bool" select="/Root/allowBookstoreErotica"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'ratingApps'" />
        <xsl:with-param name="title4" select="'App'" />
        <xsl:with-param name="valueNode" select="/Root/ratingApps" />
        <xsl:with-param name="value">
          <xsl:call-template name="ratingApps">
            <xsl:with-param name="value" select="/Root/ratingApps"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>

      <xsl:if test="$MajorVersion &gt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'forceAssistantProfanityFilter'" />
          <xsl:with-param name="title4" select="'Siri'" />
          <xsl:with-param name="title5" select="'不適切な言葉'" />
          <xsl:with-param name="valueNode" select="/Root/forceAssistantProfanityFilter" />
          <xsl:with-param name="value">
            <xsl:call-template name="falseOn">
              <xsl:with-param name="bool" select="/Root/forceAssistantProfanityFilter"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>

        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'allowAssistantUserGeneratedContent'" />
          <xsl:with-param name="title5" select="'Web検索コンテンツ'" />
          <xsl:with-param name="valueNode" select="/Root/allowAssistantUserGeneratedContent" />
          <xsl:with-param name="value">
            <xsl:call-template name="defaultOff">
              <xsl:with-param name="bool" select="/Root/allowAssistantUserGeneratedContent"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt; 7">
        <xsl:copy-of select="$restrictInApp"/>
      </xsl:if>


      <xsl:if test="$MajorVersion &gt;= 7">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'restrictWeb2'" />
          <xsl:with-param name="title4" select="'Webサイト'" />
          <xsl:with-param name="valueNode" select="/Root/restrictWeb" />
          <xsl:with-param name="value">
            <xsl:call-template name="restrictWeb">
              <xsl:with-param name="whitelistEnabled" select="/Root/restrictWeb/whitelistEnabled"/>
              <xsl:with-param name="useContentFilter" select="/Root/restrictWeb/useContentFilter"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &lt; 9">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'forceITunesStorePasswordEntry'" />
          <xsl:with-param name="title4" select="'パスワードを要求'" />
          <xsl:with-param name="valueNode" select="/Root/forceITunesStorePasswordEntry" />
          <xsl:with-param name="value">
            <xsl:call-template name="forceITunesStorePasswordEntry">
              <xsl:with-param name="value" select="forceITunesStorePasswordEntry/text()"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>

      <xsl:if test="$MajorVersion &gt;= 9">
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AccountPaidPurchasesPasswordSetting'" />
          <xsl:with-param name="title4" select="'パスワードの設定'" />
          <xsl:with-param name="title5" select="'購入とApp内課金'" />
          <xsl:with-param name="valueNode" select="/Root/AccountPaidPurchasesPasswordSetting" />
          <xsl:with-param name="value">
            <xsl:call-template name="AccountPaidPurchasesPasswordSetting">
              <xsl:with-param name="value" select="AccountPaidPurchasesPasswordSetting/text()"/>
            </xsl:call-template>
          </xsl:with-param>
        </xsl:call-template>
        
        <xsl:call-template name="settingtable">
          <xsl:with-param name="id" select="'AccountFreeDownloadsPasswordEnabled'" />
          <xsl:with-param name="title5" select="'無料ダウンロード'" />
          <xsl:with-param name="title6" select="'パスワードを要求'" />
          <xsl:with-param name="valueNode" select="/Root/AccountFreeDownloadsPasswordEnabled" />
          <xsl:with-param name="template" select="'defaultOn'" />
        </xsl:call-template>
      </xsl:if>


      <xsl:call-template name="settingtable">
        <xsl:with-param name="id" select="'SBParentalControlsCapabilities/location'" />
        <xsl:with-param name="title3" select="'プライバシー'" />
        <xsl:with-param name="title4" select="'位置情報サービス'" />
        <xsl:with-param name="title5" select="'変更を許可'" />
        <xsl:with-param name="valueNode" select="/Root/SBParentalControlsCapabilities/location" />
        <xsl:with-param name="value">
          <xsl:call-template name ="disallowModification">
            <xsl:with-param name="value" select="/Root/SBParentalControlsCapabilities/location"/>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
      
    </xsl:if>




  </xsl:template>

</xsl:stylesheet>